@@ -10,7 +10,6 @@ OC.L10N.register(
     "No activities" : "Nema aktivnosti",
     "More activities" : "Više aktivnosti",
     "Daily activity summary for %s" : "Dnevni sažetak aktivnosti za %s",
-    "_and %n more _::_and %n more _" : ["i još %n ","i još %n ","i još %n "],
     "All activities" : "Sve aktivnosti",
     "By others" : "Od drugih",
     "By you" : "Vaše",
@@ -18,14 +17,17 @@ OC.L10N.register(
     "Hello %s" : "Pozdrav %s",
     "Hello %s," : "Pozdrav %s",
     "There was some activity at %s" : "Bilo je aktivnosti na %s",
+    "_and %n more _::_and %n more _" : ["i još %n ","i još %n ","i još %n "],
+    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Možete promijeniti učestalost ovih poruka e-pošte ili ih onemogućiti u <a href=\"%s\">postavkama</a>.",
+    "You can change the frequency of these emails or disable them in the settings: %s" : "Možete promijeniti učestalost ovih poruka e-pošte ili ih onemogućiti u postavkama: %s",
     "Mail" : "Pošta",
     "Push" : "Push",
     "Activity" : "Aktivnost",
     "Notifications" : "Obavijesti",
     "This application enables people to view a log of activities about them, their files or other data." : "Ova aplikacija omogućuje korisnicima pregled aktivnosti o njima, njihovim datotekama ili ostalim podacima.",
-    "Activity notification configuration" : "Konfiguracija obavijesti o aktivnostima",
     "Send email" : "Pošalji poruku e-pošte",
     "Send push notification" : "Pošalji \"push\" notifikaciju",
+    "Activity notification configuration" : "Konfiguracija obavijesti o aktivnostima",
     "Today" : "Danas",
     "Yesterday" : "Jučer",
     "You need to set up your email address before you can receive notification emails." : "Morate navesti svoju adresu e-pošte kako biste primali poruke s obavijestima.",
@@ -47,22 +49,15 @@ OC.L10N.register(
     "Copy RSS feed link" : "Kopiraj poveznicu sažetka događaja.",
     "Personal notification settings" : "Osobne postavke obavijesti",
     "Unable to load the activity list" : "Nije moguće učitati popis aktivnosti",
-    "Notification" : "Obavijest",
-    "Enable notification emails" : "Omogući e-poštu s obavijestima",
     "Choose for which activities you want to get an email or push notification." : "Odaberite za koje aktivnosti želite primati obavijest e-poštom ili push obavijesti.",
     "Choose for which activities you want to get a push notification." : "Odaberite za koje aktivnosti želite primati push obavijesti.",
+    "Notification" : "Obavijest",
+    "Enable notification emails" : "Omogući e-poštu s obavijestima",
     "Daily activity summary" : "Dnevni sažetak aktivnosti",
     "Send daily activity summary in the morning" : "Šalji dnevni sažetak aktivnosti ujutro",
     "Default settings" : "Zadane postavke",
     "Configure the default notification settings for new accounts." : "Konfiguriraj zadane postavke obavijesti za nove račune.",
     "Unable to save the settings" : "Nije moguće spremiti postavke",
-    "No more events to load" : "Nema više događaja za učitavanje",
-    "Copied!" : "Kopirano!",
-    "Not supported!" : "Nije podržano!",
-    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
-    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
-    "{name} (invisible)" : "{name} (nevidljivo)",
-    "{name} (restricted)" : "{name} (ograničeno)",
-    "There are no events for this filter" : "Nema događaja koji odgovaraju ovom filtru"
+    "No more events to load" : "Nema više događaja za učitavanje"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
