@@ -9,9 +9,11 @@ OC.L10N.register(
     "You made {member} join {circle}" : "Ha hecho que {member} se una a {circle}",
     "{author} made {member} join {circle}" : "{author} ha hecho que {member} se una a {circle}",
     "You added team {member} as member to {circle}" : "Ha añadido al equipo {member} como miembro de {circle}",
+    "{author} added team {member} as member to {circle}" : "{author} añadió al equipo {member} como miembro de {circle}",
     "You made {member} leave {circle}" : "Ha hecho que {member} abandone {circle}",
     "{author} made {member} leave {circle}" : "{author} ha hecho que {member} abandone {circle}",
     "You removed {member} from {circle}" : "Has eliminado a {member} de {circle}",
+    "{author} removed {member} from {circle}" : "{author} eliminó a {member} de {circle}",
     "You joined {circle}" : "Te has unido a {circle}",
     "{member} joined {circle}" : "{member} se ha unido a  {circle}",
     "You accepted the invitation to join {circle}" : "Has aceptado la invitación para unirte a '{circle}'",
@@ -53,7 +55,6 @@ OC.L10N.register(
     "On events happening in a <strong>team</strong> of which you are a member" : "En eventos que suceden en un <strong>equipo</strong> del cual Ud. es miembro",
     "Any important event in a <strong>team</strong> you are moderating" : "Cualquier evento importante en un <strong>equipo</strong> el cual Ud. está moderando",
     "On global events happening in any <strong>team</strong>" : "En eventos globales que suceden en cualquier <strong>equipo</strong>",
-    "Shared to Circles" : "Compartido con Círculos",
     "Single" : "Único",
     "Personal" : "Personal",
     "System" : "Sistema",
@@ -75,8 +76,10 @@ OC.L10N.register(
     "Nextcloud Group" : "Grupo de Nextcloud",
     "Email address" : "Dirección de correo electrónico",
     "Contact" : "Contacto",
-    "Circle" : "Círculo",
+    "Team" : "Equipo",
     "Nextcloud App" : "App Nextcloud",
+    "Teams App" : "App Equipos",
+    "Admin Command Line" : "Línea de Comandos del Administrador",
     "Member" : "Participante",
     "Moderator" : "Moderador",
     "Admin" : "Administrador",
@@ -121,78 +124,45 @@ OC.L10N.register(
     "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
     "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo",
     "%s (Team owned by %s)" : "%s (Equipo propiedad de %s)",
-    "You are now a member of the Circle \"%2$s\"" : "Ahora ya eres miembro del Círculo  \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Has sido invitado por %1$s al Círculo \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s te ha enviado una solicitud para ser miembro del Círculo \"%2$s\"",
+    "You are now a member of the Team \"%2$s\"" : "Ahora eres miembro del equipo \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Has sido invitado por %1$s al equipo \"%2$s\"",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s ha enviado una solicitud para ser miembro del equipo \"%2$s\"",
     "Accept" : "Aceptar",
     "Refuse" : "Rechazar",
-    "Leave the circle" : "Abandonar el círculo",
+    "Leave the team" : "Salir del equipo",
     "%s" : "%s",
     "Personal team" : "Equipo personal",
     "%s owned by %s" : "%s propiedad de %s",
     "You have no permission to create a new team" : "No tiene permisos para crear un equipo nuevo",
     "%s shared a file with \"%s\"." : "%s compartió un archivo con \"%s\".",
     "%s shared a file with you." : "%s compartió un archivo contigo.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió con ustedes algunos contenidos.\nYa debería haber recibido un correo electrónico separado con un enlace para acceder a él.\n",
+    "%1$s shared %2$s with %3$s" : "%1$s compartió %2$s con %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s compartió %2$s con \"%3$s\"",
+    "Open %s" : "Abrir %s",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió con ustedes algunos contenidos.\nYa deberían haber recibido un correo electrónico separado con un enlace para acceder a él.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartió con ustedes algunos contenidos. Ya debería haber recibido un correo electrónico separado con un enlace para acceder a él.",
-    "Password to access content shared with you by %1$s" : "Contraseña para acceder a los archivos compartidos contigo por %1$s",
+    "Password to access content shared with you by %1$s" : "Contraseña para acceder a los archivos compartidos con Ud. por %1$s",
     "Password to access content" : "Contraseña para acceder al contenido",
     "This item is already shared with this team" : "Este ítem ya se encuentra compartido con este equipo",
     "Bring cloud-users closer together." : "Acerca a los usuarios de nubes.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Equipos le permite a los usuarios crear sus propios grupos de personas/colegas/amigos.\nEstos grupos de personas pueden ser usados por cualquier otra app para propósitos de compartición.",
+    "Failed to load teams" : "Fallo al cargar equipos",
+    "Try again" : "Vuelva a intentarlo",
+    "No teams found" : "No se encontraron equipos",
+    "Join or create teams to see them here." : "Únase o cree equipos para verlos aquí.",
+    "Create your first team" : "Cree su primer equipo",
+    "Loading…" : "Cargando…",
+    "More teams" : "Más equipos",
     "No files in here" : "No hay archivos aquí",
     "No entries found in this folder" : "No se han encontrado entradas en esta carpeta",
     "Name" : "Nombre",
     "Size" : "Tamaño",
     "Modified" : "Modificado",
-    "Circles" : "Círculos",
-    "Circles' files" : "Archivos de los círculos",
-    "Select circles to filter by" : "Selecciona los círculos por los que filtrar",
-    "No circles found" : "No se han encontrado círculos",
-    "Please select circles to filter by" : "Por favor, selecciona los círculos por los que filtrar",
-    "No files found for the selected circles" : "No se han encontrado archivos para los círculos seleccionados",
-    "You created the circle {circle}" : "Has creado el círculo {circle}",
-    "{author} created the circle {circle}" : "{author} ha creado el círculo {circle}",
-    "You added circle {member} as member to {circle}" : "Añadió al círculo {member} como miembro de {circle}",
-    "{author} added circle {member} has been added as member to {circle}" : "{author} añadió al círculo {member} como miembro de {circle}",
-    "You removed {member} leave {circle}" : "Ha eliminado a {member} y dejó {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "En eventos que suceden en un <strong>Círculo</strong> del cual eres miembro",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Cualquier evento importante en un <strong>círculo</strong> del que seas moderador",
-    "On global events happening in any <strong>Circle</strong>" : "En eventos que suceden en cualquier <strong>Círculo</strong>",
-    "Join Request" : "Solicitar Unirse",
-    "Password Protected" : "Protegido con contraseña",
-    "Circle Invite" : "Invitar al círculo",
-    "Email Address" : "Dirección de correo electrónico",
-    "Circle not found" : "No se ha encontrado el círculo",
-    "Circle not found " : "Círculo no encontrado",
-    "This account is already a member of the circle" : "Esta cuenta ya es miembro del círculo",
-    "Federated link not found" : "Enlace federado no encontrado",
-    "The circle is not federated" : "El círculo no está federado",
-    "You cannot join this circle" : "No puede unirse a este círculo",
-    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
-    "%s (Circle owned by %s)" : "%s (Círculo que pertenece a %s)",
-    "Personal Circle" : "Círculo Personal",
-    "You need a specify a type of circle" : "Necesitas especificar un tipo de círculo",
-    "A circle with that name exists" : "Ya existe un círculo con ese nombre",
-    "This member is not the owner of the circle" : "Este miebro no es el dueño del círculo",
-    "This member is not an admin of the circle" : "Este miembro no es un administrador del círculo",
-    "Group contains too many members" : "El grupo contiene demasiados miembros",
-    "This group does not exist" : "Este grupo no existe",
-    "This group is already linked to the circle" : "Este grupo ya se encuentra enlazado al círculo",
-    "You cannot edit level in a personal circle" : "No puedes editar el nivel en un círculo personal",
-    "Group cannot be set as owner of a circle" : "Un grupo no puede ser configurado como duelo de un círculo",
-    "now" : "ahora",
-    "This account does not exist" : "Esta cuenta no existe",
-    "Email format is not valid" : "El formato del correo no es válido",
-    "This contact is not available" : "Este contacto no está disponible",
-    "You have no permission to create a new circle" : "No tienes permiso para crear un nuevo círculo",
-    "This item is already shared with this circle" : "Este elemento ya ha sido compartido en este círculo",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Los círculos permiten a tus usuarios crear sus propios grupos de usuarios/compañeros/amigos.\nEstos grupos de usuarios (o \"círculos\") pueden ser utilizados por cualquier otra aplicación con el propósito de compartir información.",
     "Teams' files" : "Archivos del equipo",
     "Select team to filter by" : "Selecciona el equipo por el que filtrar",
-    "No teams found" : "No se encontraron equipos",
     "Please select teams to filter by" : "Por favor, seleccione los equipos por los que filtrar",
     "No files found for the selected teams" : "No se encontraron archivos para los equipos seleccionados",
-    "{author} added team {member} has been added as member to {circle}" : "{author} añadió al equipo {member} como miembro de {circle}"
+    "Shared to Circles" : "Compartido con Círculos",
+    "Circle" : "Círculo"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
