@@ -2,11 +2,6 @@ OC.L10N.register(
     "circles",
     {
     "Teams" : "チーム",
-    "Teams' files" : "チームのファイル",
-    "Select team to filter by" : "フィルターするチームを選択",
-    "No teams found" : "チームは見つかりませんでした",
-    "Please select teams to filter by" : "フィルターするチームを選択してください",
-    "No files found for the selected teams" : "選択したチームに割りあてられているファイルはありません",
     "You created the team {circle}" : "あなたはチーム {circle} を作成しました",
     "{author} created the team {circle}" : "{author} がチーム {circle} を作成しました",
     "You deleted {circle}" : "あなたは {circle} を削除しました",
@@ -14,10 +9,11 @@ OC.L10N.register(
     "You made {member} join {circle}" : "あなたは {member} を {circle} に加入させました",
     "{author} made {member} join {circle}" : "{author} は {member} を {circle} に加入させました",
     "You added team {member} as member to {circle}" : "あなたは {circle} にチーム {member} をメンバーとして追加しました",
-    "{author} added team {member} has been added as member to {circle}" : "{author} がチーム {member} のメンバーとして {circle} に追加されました",
+    "{author} added team {member} as member to {circle}" : "{author}がチーム{member}を{circle}のメンバーとして追加しました",
     "You made {member} leave {circle}" : "あなたは {member} を {circle} から脱退させました",
     "{author} made {member} leave {circle}" : "{author} が {member} を {circle} から脱退させました",
     "You removed {member} from {circle}" : "あなたは {member} を {circle} から除名しました",
+    "{author} removed {member} from {circle}" : "{author}が{circle}から{member}を削除しました",
     "You joined {circle}" : "あなたは {circle} に参加しました",
     "{member} joined {circle}" : "{member} が {circle} に参加しました",
     "You accepted the invitation to join {circle}" : "{circle}への招待を受け入れました",
@@ -59,7 +55,6 @@ OC.L10N.register(
     "On events happening in a <strong>team</strong> of which you are a member" : "あなたが所属する<strong>チーム</strong> で起きた出来事について",
     "Any important event in a <strong>team</strong> you are moderating" : "あなたがモデレーターを務める <strong>チーム</strong> の重要なイベント",
     "On global events happening in any <strong>team</strong>" : "どの<strong>チーム</strong>でも起きているグローバルな出来事について",
-    "Shared to Circles" : "サークルと共有",
     "Single" : "シングル",
     "Personal" : "パーソナル",
     "System" : "システム",
@@ -81,8 +76,10 @@ OC.L10N.register(
     "Nextcloud Group" : "Nextcloudグループ",
     "Email address" : "メールアドレス",
     "Contact" : "連絡先",
-    "Circle" : "サークル",
+    "Team" : "チーム",
     "Nextcloud App" : "Nextcloudアプリ",
+    "Teams App" : "Temsアプリ",
+    "Admin Command Line" : "管理者コマンドライン",
     "Member" : "メンバー",
     "Moderator" : "モデレータ",
     "Admin" : "管理者",
@@ -127,18 +124,21 @@ OC.L10N.register(
     "The account is already a member of this circle" : "そのアカウントはすでにこのサークルのメンバーです",
     "The account has already been invited into this circle" : "アカウントはすでにこのサークルに招待されています",
     "%s (Team owned by %s)" : "%s (%s が所有するサークル)",
-    "You are now a member of the Circle \"%2$s\"" : "あなたはサークル「%2$s」のメンバーではありません",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "あなたは%1$sからサークル「%2$s」に招待されています",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$sがサークル「%2$s」のメンバー申請を送りました",
+    "You are now a member of the Team \"%2$s\"" : "あなたはチーム \"%2$s\" のメンバーになりました",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "あなたは%1$sからチーム \"%2$s\"に招待されています",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$sがチーム\"%2$s\"のメンバー申請を送りました",
     "Accept" : "承諾",
     "Refuse" : "拒否する",
-    "Leave the circle" : "サークルを退会する",
+    "Leave the team" : "チームを離脱",
     "%s" : "%s",
     "Personal team" : "パーソナルチーム",
     "%s owned by %s" : "%s%sが所有",
     "You have no permission to create a new team" : "新しいチームを作成する権限がありません",
     "%s shared a file with \"%s\"." : "%sは\"%s\"どファイルを共有しました。",
     "%s shared a file with you." : "%sはあなたとファイルを共有しました。",
+    "%1$s shared %2$s with %3$s" : "%1$s は %2$s を %3$s と共有しました",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s は %2$s を \"%3$s\" と共有しました",
+    "Open %s" : "%sを開く",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s は、いくつかのコンテンツをあなたと共有しました。\nすでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s は、いくつかのコンテンツをあなたと共有しました。すでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。",
     "Password to access content shared with you by %1$s" : "%1$sが共有するコンテンツにアクセスするためのパスワード。",
@@ -146,53 +146,23 @@ OC.L10N.register(
     "This item is already shared with this team" : "このアイテムは既にこのチームで共有されています",
     "Bring cloud-users closer together." : "クラウドユーザー同士を近づける。",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "チームを使って自分のグループ(同僚、友人)を作成することができます。\nこれらのグループは、他のアプリで共有先として使用することができます。",
+    "Failed to load teams" : "チームの読込に失敗しました",
+    "Try again" : "もう一度試してください",
+    "No teams found" : "チームは見つかりませんでした",
+    "Join or create teams to see them here." : "チームに参加するか作成してここで確認してください。",
+    "Create your first team" : "最初のチームを作成する",
+    "Loading…" : "読み込み中…",
+    "More teams" : "その他のチーム",
     "No files in here" : "ファイルがありません",
     "No entries found in this folder" : "このフォルダーにはエントリーがありません",
     "Name" : "名前",
     "Size" : "サイズ",
     "Modified" : "更新日時",
-    "Circles" : "サークル",
-    "Circles' files" : "サークルのファイル",
-    "Select circles to filter by" : "フィルタリングするサークルを選択",
-    "No circles found" : "サークルが見つかりません",
-    "Please select circles to filter by" : "フィルタリングするサークルを選択してください",
-    "No files found for the selected circles" : "選択したサークルにファイルが見つかりません",
-    "You created the circle {circle}" : "サークル {circle} を作成しました",
-    "{author} created the circle {circle}" : "{author} が {circle} を作成しました",
-    "You added circle {member} as member to {circle}" : "あなたは {circle} にサークル {member} をメンバーとして追加しました",
-    "{author} added circle {member} has been added as member to {circle}" : "{author} がサークル {member} のメンバーとして {circle} に追加されました",
-    "You removed {member} leave {circle}" : "あなたは {member} を {circle} から外しました",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "あなたがメンバーである<strong>サークル</strong> で発生するイベントに応じて",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "あなたがモデレートしている <strong>Circle</strong> の重要なイベント",
-    "On global events happening in any <strong>Circle</strong>" : "いずれかの<strong>Circle</strong>で発生するグローバルなイベントに対応して",
-    "Join Request" : "参加要求",
-    "Password Protected" : "パスワードによる保護",
-    "Circle Invite" : "サークル招待",
-    "Email Address" : "電子メールアドレス",
-    "Circle not found" : "サークルが見つかりません",
-    "Circle not found " : "サークルが見つかりません",
-    "This account is already a member of the circle" : "このアカウントはすでにサークルのメンバーです",
-    "Federated link not found" : "フェデレーションリンクが見つかりません",
-    "The circle is not federated" : "サークルは統合されていません",
-    "You cannot join this circle" : "あなたはこのサークルに加入できません",
-    "This member is the owner of the circle" : "このメンバーはサークルのオーナーです",
-    "%s (Circle owned by %s)" : "%s (%sが所有するサークル)",
-    "Personal Circle" : "パーソナルサークル",
-    "You need a specify a type of circle" : "あなたはサークルのタイプを指定する必要があります",
-    "A circle with that name exists" : "その名前のサークルが存在します",
-    "This member is not the owner of the circle" : "このメンバーはサークルのオーナーではありません",
-    "This member is not an admin of the circle" : "このメンバーはサークルの管理者ではありません",
-    "Group contains too many members" : "グループに含まれるメンバー数が多すぎます",
-    "This group does not exist" : "このグループは存在しません",
-    "This group is already linked to the circle" : "このグループはすでにサークルにリンクしています",
-    "You cannot edit level in a personal circle" : "あなたは個人的なサークルのレベルを編集することはできません",
-    "Group cannot be set as owner of a circle" : "グループをサークルのオーナーとして設定することはできません",
-    "now" : "今",
-    "This account does not exist" : "このアカウントは存在しません",
-    "Email format is not valid" : "メールフォーマットが有効ではありません",
-    "This contact is not available" : "この連絡先は利用できません",
-    "You have no permission to create a new circle" : "新しいサークルを作成する権限がありません",
-    "This item is already shared with this circle" : "このアイテムは既にこのサークルで共有されています",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "サークルを使って自分のグループ(同僚、友達)を作ることができます。\n他のアプリでこれらのグループ(または「サークル」)を共有先として使用できます。"
+    "Teams' files" : "チームのファイル",
+    "Select team to filter by" : "フィルターするチームを選択",
+    "Please select teams to filter by" : "フィルターするチームを選択してください",
+    "No files found for the selected teams" : "選択したチームに割りあてられているファイルはありません",
+    "Shared to Circles" : "サークルと共有",
+    "Circle" : "サークル"
 },
 "nplurals=1; plural=0;");
