@@ -4,28 +4,8 @@ declare(strict_types=1);
 
 
 /**
- * Circles - Bring cloud-users closer together.
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2021
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
@@ -41,6 +21,7 @@ use OCA\Circles\Model\ShareWrapper;
 use OCA\Circles\Tools\Exceptions\InvalidItemException;
 use OCA\Circles\Tools\Traits\TDeserialize;
 use OCA\Circles\Tools\Traits\TStringTools;
+use OCP\Files\Folder;
 use OCP\Files\NotFoundException;
 use OCP\ICache;
 use OCP\ICacheFactory;
@@ -110,6 +91,10 @@ class ShareWrapperService {
 		$this->shareWrapperRequest->update($shareWrapper);
 	}
 
+	public function updateChildPermissions(ShareWrapper $shareWrapper): void {
+		$this->cache->clear('');
+		$this->shareWrapperRequest->updateChildPermissions($shareWrapper);
+	}
 
 	/**
 	 * @param ShareWrapper $shareWrapper
@@ -121,18 +106,17 @@ class ShareWrapperService {
 
 	/**
 	 * @param string $circleId
-	 * @param string $initiator
-	 * @param bool $force
+	 * @param string $userId
 	 *
 	 * @throws Exception
 	 */
-	public function deleteUserSharesToCircle(string $circleId, string $initiator): void {
-		if ($initiator === '') {
+	public function deleteUserSharesToCircle(string $circleId, string $userId): void {
+		if ($userId === '') {
 			throw new Exception('$initiator cannot be empty');
 		}
 
 		$this->cache->clear('');
-		$this->shareWrapperRequest->deleteSharesToCircle($circleId, $initiator);
+		$this->shareWrapperRequest->deleteSharesToCircle($circleId, $userId);
 	}
 
 
@@ -193,6 +177,17 @@ class ShareWrapperService {
 		return $this->shareWrapperRequest->getSharesByFileId($fileId, $getData);
 	}
 
+	/**
+	 * @param array $fileIds
+	 * @param bool $getData
+	 *
+	 * @return ShareWrapper[]
+	 * @throws RequestBuilderException
+	 */
+	public function getSharesByFileIds(array $fileIds, bool $getData = false, bool $getChild = false): array {
+		return ($fileIds === []) ? [] : $this->shareWrapperRequest->getSharesByFileIds($fileIds, $getData, $getChild);
+	}
+
 	/**
 	 * @param string $token
 	 * @param FederatedUser|null $federatedUser
@@ -267,14 +262,15 @@ class ShareWrapperService {
 
 	/**
 	 * @param FederatedUser $federatedUser
-	 * @param int $nodeId
+	 * @param Folder $node
 	 * @param bool $reshares
+	 * @param bool $shallow Whether the method should stop at the first level, or look into sub-folders.
 	 *
 	 * @return ShareWrapper[]
 	 * @throws RequestBuilderException
 	 */
-	public function getSharesInFolder(FederatedUser $federatedUser, int $nodeId, bool $reshares): array {
-		return $this->shareWrapperRequest->getSharesInFolder($federatedUser, $nodeId, $reshares);
+	public function getSharesInFolder(FederatedUser $federatedUser, Folder $node, bool $reshares, bool $shallow = true): array {
+		return $this->shareWrapperRequest->getSharesInFolder($federatedUser, $node, $reshares, $shallow);
 	}
 
 
