@@ -46,26 +46,31 @@ OC.L10N.register(
     "Automatically accept shares from trusted federated accounts and groups by default" : "Freigaben von vertrauenswürdigen Federations-Konten und -Gruppen standardmäßig automatisch akzeptieren",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Teile mit mir über meine #Nextcloud Federated-Cloud-ID, siehe {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Teile mit mir über meine #Nextcloud Federated-Cloud-ID",
-    "Cloud ID copied to the clipboard" : "Cloud-ID in die Zwischenablage kopiert",
-    "Copy to clipboard" : "In die Zwischenablage kopieren",
+    "Share with me via Nextcloud" : "Teile mit mir über Nextcloud",
+    "Cloud ID copied" : "Cloud-ID kopiert",
+    "Copy" : "Kopieren",
     "Clipboard not available. Please copy the cloud ID manually." : "Zwischenablage nicht verfügbar. Bitte die Cloud-ID manuell kopieren.",
     "Copied!" : "Kopiert!",
     "Federated Cloud" : "Federated Cloud",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kannst mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Gib einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
+    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kannst mit jedem teilen, der einen {productName}-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Gebe einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
     "Your Federated Cloud ID" : "Deine Federated-Cloud-ID",
     "Share it so your friends can share files with you:" : "Teile es, damit deine Freunde Dateien mit dir teilen können:",
     "Facebook" : "Facebook",
     "X (formerly Twitter)" : "X (früher Twitter)",
     "formerly Twitter" : "früher Twitter",
     "Mastodon" : "Mastodon",
+    "Bluesky" : "Bluesky",
     "Add to your website" : "Zu deiner Webseite hinzufügen",
-    "Share with me via Nextcloud" : "Teile mit mir über Nextcloud",
+    "Share with me via {productName}" : "Mit mir über {productName} teilen",
     "HTML Code:" : "HTML-Code:",
     "Cancel" : "Abbrechen",
     "Add remote share" : "Externe Freigabe hinzufügen",
     "Remote share" : "Externe Freigabe",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Soll die externe Freigabe {name} von {owner}@{remote} hinzugefügt werden?",
     "Remote share password" : "Passwort für die externe Freigabe",
-    "Incoming share could not be processed" : "Eingehende Freigabe konnte nicht verarbeitet werden"
+    "Incoming share could not be processed" : "Eingehende Freigabe konnte nicht verarbeitet werden",
+    "Cloud ID copied to the clipboard" : "Cloud-ID in die Zwischenablage kopiert",
+    "Copy to clipboard" : "In die Zwischenablage kopieren",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kannst mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Gib einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com"
 },
 "nplurals=2; plural=(n != 1);");
