@@ -13,7 +13,7 @@ OC.L10N.register(
     "Restored by {user}" : "{user} erabiltzaileak leheneratua",
     "Renamed by {user}" : "{user} erabiltzaileak berrizendatua",
     "Moved by {user}" : "{user} erabiltzaileak lekuz aldatua",
-    "\"remote account\"" : "Urrutiko kontua",
+    "\"remote account\"" : "\"urrutiko kontua\"",
     "You created {file}" : "{file} sortu duzu",
     "You created an encrypted file in {file}" : "{file} karpetan enkriptatutako fitxategi bat sortu duzu",
     "{user} created {file}" : "{user} erabiltzaileak {file} sortu du",
@@ -46,8 +46,15 @@ OC.L10N.register(
     "Failed to authorize" : "Ezin izan da baimendu",
     "Invalid folder path" : "Karpeta bide baliogabea",
     "Folder not found" : "Ez da karpeta aurkitu",
+    "The file cannot be found" : "Ezin da fitxategia aurkitu",
+    "The destination path does not exist: %1$s" : "Helburuko bidea ez dago: %1$s",
     "You do not have permission to create a file at the specified location" : "Ez duzu baimenik fitxategia sortzeko zehaztutako tokian",
     "The file could not be converted." : "Fitxategia ezin izan da bihurtu.",
+    "Could not get relative path to converted file" : "Ezin da lortu bide erlatiboa bihurtutako fitxategiarentzat",
+    "Limit must be a positive integer." : "Mugak zenbaki osoa eta positiboa izan behar du.",
+    "The replacement character may only be a single character." : "Ordezko karaktereak bakarra izan behar du.",
+    "Filename sanitization already started." : "Fitxategi-izenen garbiketa hasi da jada.",
+    "No filename sanitization in progress." : "Fitxategi-izenen garbiketa ez dago martxan.",
     "Favorite files" : "Gogoko fitxategiak",
     "No favorites" : "Gogokorik ez",
     "More favorites" : "Gogoko gehiago",
@@ -65,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{path}(r)en jabetza {user} erabiltzailetik transferitzea osatu da.",
     "in %s" : "%s(e)n",
     "Transferred from %1$s on %2$s" : "%1$s(e)tik %2$s(e)n transferitua",
-    "Files compatibility" : "Fitxategien bateragarritasuna",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Baimendu fitxategi-izenak mugatzea, fitxategiak bezero guztiekin sinkroniza daitezkeela ziurtatzeko. Lehenespenez POSIX-en balio duten fitxategi-izen guztiak (adibidez, Linux edo macOS) onartzen dira.",
-    "Enforce Windows compatibility" : "Ezarri Windows bateragarritasuna",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Honek Windows sistemetan balio ez duten fitxategi-izenak blokeatuko ditu, adibidez, izen erreserbatuak edo karaktere bereziak erabiltzea. Baina honek ez du maiuskulak eta minuskulak bereizteko bateragarritasuna beteko.",
     "File Management" : "Fitxategi-kudeaketa",
     "Home" : "Etxea",
     "Target folder does not exist any more" : "Helburuko karpeta ez da existitzen jadanik",
@@ -76,6 +79,7 @@ OC.L10N.register(
     "Go to the \"{dir}\" directory" : "Joan \"{dir}\" direktoriora",
     "Current directory path" : "Uneko direktorio-bidea",
     "Your have used your space quota and cannot upload files anymore" : "Zure espazio-kuota erabili duzu eta ezin duzu fitxategi gehiago kargatu",
+    "You do not have permission to upload or create files here." : "Ez daukazu baimenik bertan fitxategiak sortzeko edo kargatzeko.",
     "Drag and drop files here to upload" : "Jaregin fitxategiak hemen igotzeko",
     "Favorite" : "Gogokoa",
     "Back" : "Itzuli",
@@ -91,19 +95,27 @@ OC.L10N.register(
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" \"{newName}\"(e)ra berrizendatu da.",
     "Rename file" : "Berrizendatu fitxategia",
     "Folder" : "Karpeta",
+    "Unknown file type" : "Fitxategi mota ezezaguna",
+    "{ext} image" : "{ext} irudia",
+    "{ext} video" : "{ext} bideoa",
+    "{ext} audio" : "{ext} audioa",
+    "{ext} text" : "{ext} testua",
     "Pending" : "Zain",
     "Unknown date" : "Data ezezaguna",
     "Clear filter" : "Garbitu iragazkia",
     "Modified" : "Aldatuta",
+    "Search everywhere" : "Bilatu nonahi",
     "Type" : "Mota",
     "Active filters" : "Iragazki aktiboak",
     "Remove filter" : "Kendu iragazkia",
     "Total rows summary" : "Errenkaden guztirako laburpena",
     "Toggle selection for all files and folders" : "Ordeztu hautatutako fitxategi eta karpeta guztiak",
     "Name" : "Izena",
+    "File type" : "Fitxategi mota",
     "Size" : "Tamaina",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
-    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "{displayName}: failed on some elements" : "{displayName}: huts egin du elementu batzuetan",
+    "{displayName}: done" : "{displayName}: egina",
+    "{displayName}: failed" : "{displayName}: huts egin du",
     "Actions" : "Ekintzak",
     "(selected)" : "(hautatuta)",
     "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
@@ -111,7 +123,11 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Botoiak dituzten zutabeen goiburuak ordena daitezke.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
-    "{count} selected" : "{count} hautatuta",
+    "_{count} selected_::_{count} selected_" : ["{count} hautatuta","{count} hautatuta"],
+    "Search everywhere …" : "Bilatu nonahi...",
+    "Search here …" : "Bilatu hemen...",
+    "Search scope options" : "Bilaketa-eremuaren aukerak",
+    "Search here" : "Bilatu hemen",
     "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
     "{used} of {quota} used" : "{used} / {quota} erabilita",
     "{relative}% used" : "%{relative} erabilita",
@@ -123,7 +139,27 @@ OC.L10N.register(
     "Create new folder" : "Sortu karpeta berria",
     "This name is already in use." : "Izen hau dagoeneko erabiltzen ari da.",
     "Create" : "Sortu",
+    "Files starting with a dot are hidden by default" : "Puntu batez hasten diren fitxategiak ezkutatuta daude",
+    "Failed to start filename sanitization." : "Ezin izan da fitxategi-izenen garbiketa abiatu.",
+    "Failed to refresh filename sanitization status." : "Ezin izan da fitxategi-izenen garbiketa egoera freskatu.",
+    "Filename sanitization in progress." : "Fitxategi-izenen garbiketa martxan da.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Une honetan {totalUsers}kontuetatik {processedUsers}prozesatu dira.",
+    "Preparing …" : "Prestatzen...",
+    "Refresh" : "Freskatu",
+    "All files have been santized for Windows filename support." : "Fitxategi guztiak garbitu dira Windows-en fitxategi-izenaren onarpenerako.",
+    "Some files could not be sanitized, please check your logs." : "Fitxategi batzuk ezin izan dira garbitu, begiratu erregistroak.",
+    "Sanitization errors" : "Garbiketa erroreak",
+    "Not sanitized filenames" : "Garbitu gabeko fitxategi-izenak",
+    "Windows filename support has been enabled." : "Windows-en fitxategi-izenen onarpena aktibatu da.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Honek erabiltzaileei onartzen ez diren fitxategi-izenekin fitxategi berriak sortzea eragozten dien bitartean, existitzen diren fitxategiak ez dira oraindik izenez aldatuko eta, beraz, Windows-en sinkronizazioa eten daiteke.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Fitxategi-izen baliogabea duten fitxategien izenak alda ditzakezu. Hori bigarren planoan egingo da, eta baliteke denbora pixka bat behar izatea.",
+    "Please note that this may cause high workload on the sync clients." : "Kontuan izan horrek lan-karga handia eragin diezaiekeela sinkronizazio-bezeroei.",
+    "Limit" : "Muga",
+    "This allows to configure how many users should be processed in one background job run." : "Honek atzeko planoko exekuzio batean zenbat erabiltzaile prozesatu behar diren konfiguratzeko aukera ematen du.",
+    "Sanitize filenames" : "Garbitu fitxategi-izenak",
+    "(starting)" : "(abiatzen)",
     "Fill template fields" : "Bete txantiloien eremuak",
+    "Submitting fields …" : "Bidaltzeko eremuak",
     "Submit" : "Bidali",
     "Choose a file or folder to transfer" : "Aukeratu fitxategi edo karpeta bat transferitzeko",
     "Transfer" : "Transferitu",
@@ -136,12 +172,15 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
     "Change" : "Aldatu",
     "New owner" : "Jabe berria",
+    "Keep {old}" : " {old} mantendu",
+    "Keep without extension" : "Mantendu luzapenik gabe",
     "Use {new}" : "Erabili {new}",
     "Remove extension" : "Kendu luzapena",
     "Change file extension" : "Aldatu fitxategiaren luzapena",
     "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Fitxategiaren luzapena «{old}»(e)tik «{new}»(e)ra aldatzeak irakurezin bihur dezake.",
     "Removing the file extension \"{old}\" may render the file unreadable." : "«{old}» fitxategiaren luzapena kentzeak fitxategia irakurezin bihur dezake.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "«{new}» fitxategiaren luzapena gehitzeak fitxategia irakurezin bihur dezake.",
+    "Do not show this dialog again." : "Ez erakutsi elkarrizketa hau berriro",
     "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
     "Choose {file}" : "Aukeratu {file}",
     "Share" : "Partekatu",
@@ -149,13 +188,13 @@ OC.L10N.register(
     "Shared" : "Partekatuta",
     "Switch to list view" : "Aldatu zerrenda ikuspegira",
     "Switch to grid view" : "Aldatu sareta ikuspegira",
+    "The file could not be found" : "Fitxategiaren hodeia ez da aurkitu",
     "Upload was cancelled by user" : "Igoera bertan behera utzi du erabiltzaileak",
     "Not enough free space" : "Ez dago leku libre nahikorik",
     "Operation is blocked by access control" : "Sarbide kontrolak eragiketa blokeatu du",
     "Error during upload: {message}" : "Errorea igotzean: {message}",
     "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
     "Unknown error during upload" : "Errore ezezaguna igotzean",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
     "Loading current folder" : "Uneko karpeta kargatzen",
     "Retry" : "saiatu berriro",
     "No files in here" : "Ez dago fitxategirik hemen",
@@ -167,44 +206,61 @@ OC.L10N.register(
     "Open in files" : "Ireki Fitxategiak aplikazioan",
     "File cannot be accessed" : "Ezin da fitxategia atzitu",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
+    "No search results for “{query}”" : "Ez da aurkitu emaitzarik “{query}” kontsultarentzat",
+    "Search for files" : "Bilatu fitxategiak",
     "Clipboard is not available" : "Arbela ez dago erabilgarri",
-    "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
+    "WebDAV URL copied" : "WebDAV URLa kopiatu da",
+    "General" : "Orokorra",
+    "Default view" : "Ikuspegi lehenetsia",
+    "All files" : "Fitxategi guztiak",
+    "Personal files" : "Fitxategi pertsonalak",
     "Sort favorites first" : "Ordenatu gogokoak lehenengo",
     "Sort folders before files" : "Ordenatu karpetak fitxategien aurretik",
+    "Folder tree" : "Fitxategien zuhaitza",
+    "Appearance" : "Itxura",
     "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
+    "Show file type column" : "Erakutsi fitxategi luzapenen zutabea",
+    "Show file extensions" : "Erakutsi fitxategien luzapena",
     "Crop image previews" : "Moztu irudien aurrebistak",
-    "Enable the grid view" : "Gaitu sareta ikuspegira",
-    "Enable folder tree" : "Gaitu karpeta-zuhaitza",
     "Additional settings" : "Ezarpen gehiago",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URLa",
-    "Copy to clipboard" : "Kopiatu arbelera",
-    "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
+    "Copy" : "Kopiatu",
+    "How to access files using WebDAV" : "Nola sartu fitxategietara WebDAV erabiliz",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Bi faktoreko autentifikazioa aktibatuta dago zure kontuan, eta, beraz, aplikazioaren pasahitza erabili behar duzu kanpoko WebDAV bezero bat konektatzeko.",
+    "Warnings" : "Oharrak",
+    "Warn before changing a file extension" : "Abisatu fitxategiaren luzapena aldatu aurretik",
+    "Warn before deleting files" : "Abisatu fitxategiak ezabatu aurretik",
     "Keyboard shortcuts" : "Teklatuaren lasterbideak",
-    "Speed up your Files experience with these quick shortcuts." : "Azkartu zure Fitxategi esperientzia lasterbide bizkor hauekin",
-    "Open the actions menu for a file" : "Ireki ekintza menua fitxategi baterako",
-    "Rename a file" : "Fitxategi bat berrizendatu",
-    "Delete a file" : "Fitxategi bat ezabatu",
-    "Favorite or remove a file from favorites" : "Fitxategi bat gustoko bihurtu edo gustoko izateari utzi",
-    "Manage tags for a file" : "Fitxategi baten etiketak kudeatu",
+    "File actions" : "Fitxategi ekintzak",
+    "Rename" : "Berrizendatu",
+    "Delete" : "Ezabatu",
+    "Add or remove favorite" : "Gehitu edo kendu gogokoetatik",
+    "Manage tags" : "Kudeatu etiketak",
     "Selection" : "Hautapena",
     "Select all files" : "Fitxategi guztiak aukeratu",
-    "Deselect all files" : "Fitxategi guztiak desaukeratu",
-    "Select or deselect a file" : "Fitxategi bat aukeratu edo desaukeratu",
-    "Select a range of files" : "Fitxategi-hein bat aukeratu",
+    "Deselect all" : "Deshautatu dena",
+    "Select or deselect" : "Hautatu edo desautatu",
+    "Select a range" : "Hautatu tarte bat",
     "Navigation" : "Nabigazioa",
-    "Navigate to the parent folder" : "Nabigatu guraso karpetara",
-    "Navigate to the file above" : "Nabigatu goiko fitxategira",
-    "Navigate to the file below" : "Nabigatu azpiko fitxategira",
-    "Navigate to the file on the left (in grid mode)" : "Nabigatu ezkerreko fitxategira (sareta moduan)",
-    "Navigate to the file on the right (in grid mode)" : "Nabigatu eskuineko fitxategira (sareta moduan)",
+    "Go to parent folder" : "Joan karpeta gurasora",
+    "Go to file above" : "Joan goiko fitxategira",
+    "Go to file below" : "Joan beheko fitxategira",
+    "Go left in grid" : "Joan ezkerrera saretan",
+    "Go right in grid" : "Joan eskuinera saretan",
     "View" : "Ikusi",
-    "Toggle the grid view" : "Txandakatu sareta ikuspegia",
-    "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako",
+    "Toggle grid view" : "Txandakatu sareta ikuspegia",
+    "Open file sidebar" : "Ireki alboko barra",
     "Show those shortcuts" : "Erakutsi lasterbide horiek",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Baimendu fitxategi-izenak mugatzea, fitxategiak bezero guztiekin sinkroniza daitezkeela ziurtatzeko. Lehenespenez POSIX-en balio duten fitxategi-izen guztiak (adibidez, Linux edo macOS) onartzen dira.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows-ekin bateragarriak diren fitxategi-izenak gaitu ondoren, lehendik dauden fitxategiak ezin dira gehiago aldatu, baina jabeak baliozko izen berria eman diezaioke.",
+    "Failed to toggle Windows filename support" : "Huts egin du Windows-en fitxategi-izenen onarpena aldatzeak",
+    "Files compatibility" : "Fitxategien bateragarritasuna",
+    "Enforce Windows compatibility" : "Ezarri Windows bateragarritasuna",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Honek Windows sistemetan balio ez duten fitxategi-izenak blokeatuko ditu, adibidez, izen erreserbatuak edo karaktere bereziak erabiltzea. Baina honek ez du maiuskulak eta minuskulak bereizteko bateragarritasuna beteko.",
     "You" : "Zu ",
     "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
+    "Unable to change the favorite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
     "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
     "Owner" : "Jabea",
     "Remove from favorites" : "Kendu gogokoetatik",
@@ -215,7 +271,20 @@ OC.L10N.register(
     "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
     "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
     "Creating file" : "Fitxategia sortzen",
-    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
+    "Save as {displayName}" : "Gorde honela: {displayName}",
+    "Save as …" : "Gorde honela...",
+    "Converting files …" : "Fitxategiak bihurtzen...",
+    "Failed to convert files: {message}" : "Huts egin du fitxategiak bihurtzeak: {message}",
+    "All files failed to be converted" : "Huts egin du fitxategi guztiak bihurtzean",
+    "One file could not be converted: {message}" : "Fitxategi bat ezin izan da bihurtu: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Fitxategi bat ezin izan da bihurtu","%n fitxategi ezin izan dira bihurtu"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Fitxategi bat behar bezala bihurtu da","%n fitxategi behar bezala bihurtu dira"],
+    "Files successfully converted" : "Fitxategiak behar bezala bihurtu dira",
+    "Failed to convert files" : "Huts egin du fitxategien bihurtzeak",
+    "Converting file …" : "Fitxategia bihurtzen...",
+    "File successfully converted" : "Fitxategia behar bezala bihurtu da",
+    "Failed to convert file: {message}" : "Fitxategi honen bihurtzeak huts egin du: {message}",
+    "Failed to convert file" : "Huts egin du fitxategiaren bihurtzeak",
     "Leave this share" : "Utzi partekatze hau",
     "Leave these shares" : "Utzi partekatze hauek",
     "Disconnect storage" : "Deskonektatu biltegia",
@@ -226,29 +295,29 @@ OC.L10N.register(
     "Delete files" : "Ezabatu fitxategiak",
     "Delete folder" : "Ezabatu karpeta",
     "Delete folders" : "Ezabatu karpetak",
-    "Delete" : "Ezabatu",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Elementu {count} betiko ezabatzera zoaz","{count} elementu betiko ezabatzera zoaz"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Elementu {count} ezabatzera zoaz"," {count}  elementu ezabatzera zoaz"],
     "Confirm deletion" : "Berretsi ezabaketa",
     "Cancel" : "Utzi",
+    "Download" : "Deskargatu",
+    "The requested file is not available." : "Eskatutako fitxategia ez dago eskuragarri.",
+    "The requested files are not available." : "Eskatutako fitxategiak ez daude eskuragarri.",
     "Moving \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
     "Copying \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
+    "Destination is not a folder" : "Helburua ez da karpeta bat",
+    "This file/folder is already in that directory" : "Fitxategi/karpeta hau dagoeneko karpeta horretan dago",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
     "(copy)" : "(kopiatu)",
     "(copy %n)" : "(kopiatu %n)",
-    "Move cancelled" : "Mugimendua bertan behera utzi da",
     "A file or folder with that name already exists in this folder" : "Izen hori duen fitxategi edo karpeta bat dago karpena honetan",
     "The files are locked" : "Fitxategiak blokeatuta daude",
     "The file does not exist anymore" : "Fitxategia ez da existizen dagoeneko",
     "Choose destination" : "Aukeratu helburua",
     "Copy to {target}" : "Kopiatu hona: {target}",
-    "Copy" : "Kopiatu",
     "Move to {target}" : "Mugitu hona: {target}",
     "Move" : "Mugitu",
     "Move or copy operation failed" : "Mugitzeko edo kopiatzeko eragiketak huts egin du",
     "Move or copy" : "Mugitu edo kopiatu",
-    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" -ren mugimendua edo kopia bertan behera utzi da.",
-    "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
     "Open folder {displayName}" : "Ireki {displayName} karpeta",
     "Open in Files" : "Ireki Fitxategiak aplikazioan",
     "Open locally" : "Ireki lokalean",
@@ -256,8 +325,8 @@ OC.L10N.register(
     "Open file locally" : "Ireki fitxategia lokalean",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fitxategia orain zure gailuan ireki beharko litzateke. Hala ez bada, egiaztatu mahaigaineko aplikazioa instalatuta duzula.",
     "Retry and close" : "Saiatu berriro eta itxi",
-    "Rename" : "Berrizendatu",
-    "Open details" : "Ireki xehetasunak",
+    "Open online" : "Ireki linean",
+    "Details" : "Xehetasunak",
     "View in folder" : "Ikusi karpetan",
     "Today" : "Gaur",
     "Last 7 days" : "Azken 7 egunetan",
@@ -270,15 +339,15 @@ OC.L10N.register(
     "PDFs" : "PDFak",
     "Folders" : "Karpetak",
     "Audio" : "Audio",
-    "Photos and images" : "Argazkiak eta irudiak",
+    "Images" : "Irudiak",
     "Videos" : "Bideoak",
-    "New folder creation cancelled" : "Karpeta berrien sorrera bertan behera utzi da",
     "Created new folder \"{name}\"" : "\"{name}\" karpeta berria sortu da",
     "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
     "Create templates folder" : "Sortu txantiloien karpeta",
     "Templates" : "Txantiloiak",
     "New template folder" : "Txantiloien karpeta berria",
     "In folder" : "Karpetan",
+    "Search in all files" : "Bilatu fitxategi guztietan",
     "Search in folder: {folder}" : "Bilatu {folder} karpetan",
     "One of the dropped files could not be processed" : "Jaregindako fitxategietako bat ezin izan da prozesatu",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Zure nabigatzaileak ez du Filesystem APIa onartzen. Direktorioak ez dira igoko",
@@ -293,12 +362,16 @@ OC.L10N.register(
     "Files moved successfully" : "Fitxategiak behar bezala mugitu dira",
     "Conflicts resolution skipped" : "Gatazkak konpontzea saihestu da",
     "Upload cancelled" : "Igotzea bertan behera utzi da",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Ezin izan da \"{oldName}\" berrizendatu, ez da existitzen dagoeneko",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" izena \"{dir}\" karpetan dagoeneko erabiltzen da. Mesedez aukeratu beste izen bat.",
+    "Could not rename \"{oldName}\"" : "Ezin izan da \"{oldName}\" berrizendatu ",
     "This operation is forbidden" : "Eragiketa hau debekatuta dago",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
+    "This folder is unavailable, please try again later or contact the administration" : "Karpeta hau ez dago erabilgarri. Saiatu geroago edo jarri harremanetan administrazioarekin",
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
     "Unexpected error: {error}" : "Ustekabeko errorea: {error}",
     "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
     "_%n folder_::_%n folders_" : ["Karpeta %n","%n karpeta"],
+    "_%n hidden_::_%n hidden_" : ["%n ezkutuan","%n ezkutuan"],
     "Filename must not be empty." : "Fitxategi-izenak ez du hutsik egon behar.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" izen erreserbatua da eta ez da onartzen fitxategi-izenetan.",
@@ -307,10 +380,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Gogoko fitxategi eta karpeten zerrenda.",
     "No favorites yet" : "Gogokorik ez oraindik",
     "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
-    "All files" : "Fitxategi guztiak",
     "List of your files and folders." : "Zure fitxategi eta karpeten zerrenda.",
-    "All folders" : "Karpeta guztiak",
-    "Personal files" : "Fitxategi pertsonalak",
     "List of your files and folders that are not shared." : "Partekatu ez diren zure fitxategi eta karpeten zerrenda.",
     "No personal files found" : "Ez dago fitxategi pertsonalik",
     "Files that are not shared will show up here." : "Partekatu ez dituzun fitxategiak hemen agertuko dira",
@@ -318,12 +388,13 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Azkenaldian aldatutako fitxategi eta karpeten zerrenda.",
     "No recently modified files" : "Ez dago azkenaldian aldatutako fitxategirik",
     "Files and folders you recently modified will show up here." : "Azkenaldian aldatu dituzun fitxategi eta karpetak hemen agertuko dira.",
+    "Search" : "Bilatu",
+    "Search results within your files." : "Bilatu emaitzak zure fitxategien barruan.",
     "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
     "Select all" : "Hautatu dena",
     "Upload too large" : "Igotzekoa handiegia da",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiek zerbitzari honek onartzen duen gehienezko tamaina gainditzen dute.",
     "File could not be found" : "Ezin izan da fitxategia aurkitu",
-    "Download" : "Deskargatu",
     "Show list view" : "Erakutsi zerrenda ikuspegia",
     "Show grid view" : "Erakutsi sareta ikuspegia",
     "Close" : "Itxi",
@@ -348,12 +419,12 @@ OC.L10N.register(
     "Edit locally" : "Editatu lokalean",
     "Open" : "Ireki",
     "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
-    "Details" : "Xehetasunak",
     "Please select tag(s) to add to the selection" : "Hautatu etiketa(k) hautapenera gehitzeko",
     "Apply tag(s) to selection" : "Aplikatu etiketa(k) hautapenari",
     "Select directory \"{dirName}\"" : "Hautatu \"{dirName}\" direktorioa",
     "Select file \"{fileName}\"" : "Hautatu \"{fileName}\" fitxategia",
     "Unable to determine date" : "Ezin izan da data zehaztu",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
     "Could not move \"{file}\", target exists" : "Ezin izan da \"{file}\" lekuz aldatu, helburua existitzen da jadanik",
     "Could not move \"{file}\"" : "Ezin izan da \"{file}\" lekuz aldatu",
     "copy" : "kopiatu",
@@ -362,9 +433,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "{origin} kopiatu da {destination} barruan",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} eta beste {nbfiles} fitxategi {destination} barruan kopiatu dira",
     "{newName} already exists" : "{newName} existitzen da dagoeneko",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Ezin izan da \"{fileName}\" berrizendatu, ez da existitzen jada",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" izena dagoeneko erabiltzen da \"{dir}\" karpetan. Aukeratu beste izen bat.",
-    "Could not rename \"{fileName}\"" : "Ezin izan da \"{fileName}\" berrizendatu ",
     "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
     "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
     "Could not create folder \"{dir}\" because it already exists" : "Ezin izan da \"{dir}\" karpeta sortu, dagoeneko existitzen delako",
@@ -404,15 +472,56 @@ OC.L10N.register(
     "Not favored" : "Mesedetu gabe",
     "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzen saiatzean",
     "Upload (max. %s)" : "Igo (%s gehienez)",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
+    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\"-k huts egin du zenbait elementutan",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
     "Submitting fields…" : "Eremuak bidaltzen…",
     "Filter filenames…" : "Iragazi fitxategi-izenak...",
+    "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
+    "Enable the grid view" : "Gaitu sareta ikuspegira",
+    "Enable folder tree" : "Gaitu karpeta-zuhaitza",
+    "Copy to clipboard" : "Kopiatu arbelera",
+    "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
+    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
+    "Move cancelled" : "Mugimendua bertan behera utzi da",
+    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" -ren mugimendua edo kopia bertan behera utzi da.",
+    "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
+    "Open details" : "Ireki xehetasunak",
+    "Photos and images" : "Argazkiak eta irudiak",
+    "New folder creation cancelled" : "Karpeta berrien sorrera bertan behera utzi da",
     "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
     "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
+    "All folders" : "Karpeta guztiak",
     "Personal Files" : "Fitxategi pertsonalak",
     "Text file" : "Testu-fitxategia",
-    "New text file.txt" : "Testu-fitxategi berria.txt"
+    "New text file.txt" : "Testu-fitxategi berria.txt",
+    "%1$s (renamed)" : "%1$s (berrizendatua)",
+    "renamed file" : "fitxategia berrizendatu da",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows-ekin bateragarriak diren fitxategi-izenak gaitu ondoren, lehendik dauden fitxategiak ezin dira gehiago aldatu, baina jabeak baliozko izen berria jar diezaieke.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Fitxategiak automatikoki migratu daitezke ezarpen hau gaitu ondoren. Kontsultatu occ komandoari buruzko dokumentazioa.",
+    "Filter file names …" : "Iragazi fitxategien izenak...",
+    "Prevent warning dialogs from open or reenable them." : "Ohar-elkarrizketak ez irekitzea edo berriro aktibatzea.",
+    "Show a warning dialog when changing a file extension." : "Erakutsi oharra fitxategi baten luzapena aldatzean",
+    "Speed up your Files experience with these quick shortcuts." : "Azkartu zure Fitxategi esperientzia lasterbide bizkor hauekin",
+    "Open the actions menu for a file" : "Ireki ekintza menua fitxategi baterako",
+    "Rename a file" : "Fitxategi bat berrizendatu",
+    "Delete a file" : "Fitxategi bat ezabatu",
+    "Favorite or remove a file from favorites" : "Fitxategi bat gustoko bihurtu edo gustoko izateari utzi",
+    "Manage tags for a file" : "Fitxategi baten etiketak kudeatu",
+    "Deselect all files" : "Fitxategi guztiak desaukeratu",
+    "Select or deselect a file" : "Fitxategi bat aukeratu edo desaukeratu",
+    "Select a range of files" : "Fitxategi-hein bat aukeratu",
+    "Navigate to the parent folder" : "Nabigatu guraso karpetara",
+    "Navigate to the file above" : "Nabigatu goiko fitxategira",
+    "Navigate to the file below" : "Nabigatu azpiko fitxategira",
+    "Navigate to the file on the left (in grid mode)" : "Nabigatu ezkerreko fitxategira (sareta moduan)",
+    "Navigate to the file on the right (in grid mode)" : "Nabigatu eskuineko fitxategira (sareta moduan)",
+    "Toggle the grid view" : "Txandakatu sareta ikuspegia",
+    "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako"
 },
 "nplurals=2; plural=(n != 1);");
