@@ -1,10 +1,10 @@
 OC.L10N.register(
     "files",
     {
-    "Added to favorites" : "已添加到收藏夹",
-    "Removed from favorites" : "从收藏夹移除",
-    "You added {file} to your favorites" : "您已经添加 {file} 到您的收藏夹",
-    "You removed {file} from your favorites" : "您已从收藏夹中移除 {file}",
+    "Added to favorites" : "已添加到收藏",
+    "Removed from favorites" : "已从收藏中移除",
+    "You added {file} to your favorites" : "您已将 {file} 添加到收藏",
+    "You removed {file} from your favorites" : "您已从收藏中移除 {file}",
     "Favorites" : "收藏",
     "File changes" : "文件变动",
     "Created by {user}" : "由 {user} 创建",
@@ -51,10 +51,13 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "您没有在指定位置创建文件的权限",
     "The file could not be converted." : "无法转换文件。",
     "Could not get relative path to converted file" : "无法获取转换文件的相对路径",
+    "Limit must be a positive integer." : "限制必须是正整数。",
+    "The replacement character may only be a single character." : "替换字符只能是单个字符。",
+    "Filename sanitization already started." : "文件名清理已开始。",
+    "No filename sanitization in progress." : "没有正在进行的文件名清理。",
     "Favorite files" : "收藏的文件",
     "No favorites" : "无收藏",
     "More favorites" : "更多收藏",
-    "Upload (max. %s)" : "上传 （最大 %s）",
     "Accept" : "接受",
     "Reject" : "拒绝",
     "Incoming ownership transfer from {user}" : "来自 {user} 的所有权转移",
@@ -69,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "来自 {user} 的 {path} 的所有权转移已完成。",
     "in %s" : "在 %s",
     "Transferred from %1$s on %2$s" : "从 %1$s 转移至 %2$s",
-    "Files compatibility" : "文件兼容性",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允许限制文件名称以确保文件可以与所有客户端同步。默认状态下，所有POSIX（例如 Linux 或 macOS）系统有效的文件名都是被允许的。",
-    "Enforce Windows compatibility" : "强制 Windows 兼容性",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "这将阻止在 Windows 系统中无效的文件名称，比如使用保留字符。但这不会强制大小写敏感性兼容。",
     "File Management" : "文件管理",
     "Home" : "首页",
     "Target folder does not exist any more" : "目标文件夹已不存在",
@@ -95,31 +94,43 @@ OC.L10N.register(
     "Invalid filename." : "无效文件名称。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "已将“{oldName}”重命名为“{newName}”",
     "Rename file" : "重命名文件",
+    "Folder" : "文件夹",
+    "Unknown file type" : "未知文件类型",
+    "{ext} image" : "{ext} 图片",
+    "{ext} video" : "{ext} 视频",
+    "{ext} audio" : "{ext} 音频",
+    "{ext} text" : "{ext} 文本",
     "Pending" : "等待",
     "Unknown date" : "未知日期",
     "Clear filter" : "清除筛选",
     "Modified" : "修改日期",
+    "Search everywhere" : "在所有位置搜索",
     "Type" : "类型",
     "Active filters" : "已开启的过滤器",
     "Remove filter" : "移除过滤条件",
     "Total rows summary" : "总行摘要",
     "Toggle selection for all files and folders" : "切换所有文件和文件夹的选择",
     "Name" : "名称",
+    "File type" : "文件类型",
     "Size" : "大小",
-    "\"{displayName}\" failed on some elements" : "“{displayName}”在某些元素上失败",
-    "\"{displayName}\" batch action executed successfully" : "批量操作“{displayName}”运行成功",
-    "\"{displayName}\" action failed" : "“{displayName}”操作执行失败",
+    "{displayName}: failed on some elements" : "{displayName}：在部分上元素失败",
+    "{displayName}: done" : "{displayName}：完成",
+    "{displayName}: failed" : "{displayName}：失败",
     "Actions" : "操作",
-    "(selected)" : "（选中）",
+    "(selected)" : "（已选择）",
     "List of files and folders." : "文件与文件夹列表。",
     "You have used your space quota and cannot upload files anymore." : "您的剩余空间配额不足以继续上传文件。",
     "Column headers with buttons are sortable." : "带有按钮的列标题可进行排序。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出于性能考虑，此列表未完全呈现。文件将在您浏览列表时呈现。",
     "File not found" : "文件未找到",
-    "{count} selected" : "已选中 {count}",
-    "{usedQuotaByte} used" : "{usedQuotaByte} 已使用",
-    "{used} of {quota} used" : "已使用 {used} / {quota}",
-    "{relative}% used" : "{relative}% 已使用",
+    "_{count} selected_::_{count} selected_" : ["已选择 {count} 个"],
+    "Search everywhere …" : "在所有位置搜索…",
+    "Search here …" : "在此搜索…",
+    "Search scope options" : "搜索范围选项",
+    "Search here" : "在此搜索",
+    "{usedQuotaByte} used" : "已使用 {usedQuotaByte}",
+    "{used} of {quota} used" : "已使用 {used}（共 {quota}）",
+    "{relative}% used" : "已使用 {relative}%",
     "Could not refresh storage stats" : "无法刷新存储统计数据",
     "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
     "Storage information" : "存储信息",
@@ -128,6 +139,25 @@ OC.L10N.register(
     "Create new folder" : "创建新文件夹",
     "This name is already in use." : "此名称已被使用。",
     "Create" : "创建",
+    "Files starting with a dot are hidden by default" : "以点开头的文件默认是隐藏的",
+    "Failed to start filename sanitization." : "无法启动文件名清理。",
+    "Failed to refresh filename sanitization status." : "无法刷新文件名清理状态。",
+    "Filename sanitization in progress." : "正在进行文件名清理。",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "目前已处理 {processedUsers} 个账号，共 {totalUsers} 个。",
+    "Preparing …" : "正在准备…",
+    "Refresh" : "刷新",
+    "All files have been santized for Windows filename support." : "所有文件都已清理，以支持 Windows 文件名。",
+    "Some files could not be sanitized, please check your logs." : "部分文件无法进行清理，请检查您的日志。",
+    "Sanitization errors" : "清理错误",
+    "Not sanitized filenames" : "未清理的文件名",
+    "Windows filename support has been enabled." : "Windows 文件名支持已启用。",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "虽然这会阻止用户使用不受支持的文件名创建新文件，但现有文件尚未重命名，因此仍可能在 Windows 上中断同步。",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "您可以触发对具有无效文件名的文件进行重命名，这将在后台完成，可能需要一些时间。",
+    "Please note that this may cause high workload on the sync clients." : "请注意，这可能会导致同步客户端的工作负载很高。",
+    "Limit" : "限制",
+    "This allows to configure how many users should be processed in one background job run." : "这允许配置在一个后台作业运行中应处理多少用户。",
+    "Sanitize filenames" : "清理文件名",
+    "(starting)" : "（正在启动）",
     "Fill template fields" : "填写模板字段",
     "Submitting fields …" : "正在提交字段…",
     "Submit" : "使用",
@@ -165,64 +195,76 @@ OC.L10N.register(
     "Error during upload: {message}" : "上传时发生错误: {message}",
     "Error during upload, status code {status}" : "上传时发生错误，状态码 {status}",
     "Unknown error during upload" : "上传时发生未知错误",
-    "\"{displayName}\" action executed successfully" : "“{displayName}”操作执行成功",
     "Loading current folder" : "正在载入当前文件夹",
     "Retry" : "重试",
     "No files in here" : "这里没有文件",
     "Upload some content or sync with your devices!" : "上传一些内容或与您的设备同步！",
     "Go back" : "返回",
-    "Filter file names …" : "筛选文件名…",
     "Views" : "视图",
     "Files settings" : "文件设置",
     "Your files" : "你的文件",
     "Open in files" : "在文件中打开",
     "File cannot be accessed" : "文件无法访问",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到该文件，或是您没有查看该文件的权限。请要求发送者分享它。",
+    "No search results for “{query}”" : "没有“{query}”的搜索结果",
+    "Search for files" : "搜索文件",
     "Clipboard is not available" : "剪贴板不可用",
-    "WebDAV URL copied to clipboard" : "WebDAV 链接已复制到剪贴板",
+    "WebDAV URL copied" : "WebDAV URL 已复制",
+    "General" : "常规",
+    "Default view" : "默认视图",
+    "All files" : "全部文件",
+    "Personal files" : "个人文件",
     "Sort favorites first" : "收藏排序优先",
     "Sort folders before files" : "将文件夹排在文件前面",
+    "Folder tree" : "文件夹树",
+    "Appearance" : "外观",
     "Show hidden files" : "显示隐藏文件",
+    "Show file type column" : "显示文件类型列",
+    "Show file extensions" : "显示文件扩展名",
     "Crop image previews" : "裁剪图片预览",
-    "Enable the grid view" : "启用网格视图",
-    "Enable folder tree" : "启用文件夹树",
     "Additional settings" : "其他设置",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "复制到剪贴板",
-    "Use this address to access your Files via WebDAV" : "使用此地址通过 WebDAV 访问您的文件",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果启用两步验证，您必须点击此处来创建和使用一个新的应用程序密码。",
+    "Copy" : "复制",
+    "How to access files using WebDAV" : "如何使用 WebDAV 访问文件",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "您的账号已启用双因素身份验证，因此您需要使用应用密码来连接外部 WebDAV 客户端。",
     "Warnings" : "警告",
-    "Prevent warning dialogs from open or reenable them." : "防止打开或重新启用警告对话框。",
-    "Show a warning dialog when changing a file extension." : "更改文件扩展名时显示警告对话框。",
+    "Warn before changing a file extension" : "更改文件扩展名前发出警告",
+    "Warn before deleting files" : "删除文件前发出警告",
     "Keyboard shortcuts" : "键盘快捷键",
-    "Speed up your Files experience with these quick shortcuts." : "这些快捷键可以加快你的“文件”体验。",
-    "Open the actions menu for a file" : "打开文件的操作菜单",
-    "Rename a file" : "重命名文件",
-    "Delete a file" : "删除文件",
-    "Favorite or remove a file from favorites" : "把文件添加或移除出收藏夹",
-    "Manage tags for a file" : "管理文件的标签",
+    "File actions" : "文件操作",
+    "Rename" : "重命名",
+    "Delete" : "删除",
+    "Add or remove favorite" : "添加或移除收藏",
+    "Manage tags" : "管理标签",
     "Selection" : "选择",
     "Select all files" : "选择所有文件",
-    "Deselect all files" : "取消选择所有文件",
-    "Select or deselect a file" : "选择或取消选择文件",
-    "Select a range of files" : "选择一系列文件",
+    "Deselect all" : "全部取消选择",
+    "Select or deselect" : "选择或取消选择",
+    "Select a range" : "选择范围",
     "Navigation" : "导航",
-    "Navigate to the parent folder" : "前往上一级文件夹",
-    "Navigate to the file above" : "跳转至以上文件",
-    "Navigate to the file below" : "跳转至以下文件",
-    "Navigate to the file on the left (in grid mode)" : "跳转至左侧文件（在网格模式下）",
-    "Navigate to the file on the right (in grid mode)" : "跳转至右侧文件（在网格模式下）",
+    "Go to parent folder" : "转到上层文件夹",
+    "Go to file above" : "转到上方文件",
+    "Go to file below" : "转到下方文件",
+    "Go left in grid" : "在网格中向左",
+    "Go right in grid" : "在网格中向右",
     "View" : "查看",
-    "Toggle the grid view" : "切换网格视图",
-    "Open the sidebar for a file" : "在侧边栏打开文件",
+    "Toggle grid view" : "切换网格视图",
+    "Open file sidebar" : "打开文件侧边栏",
     "Show those shortcuts" : "显示快捷键",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允许限制文件名称以确保文件可以与所有客户端同步。默认状态下，所有POSIX（例如 Linux 或 macOS）系统有效的文件名都是被允许的。",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "启用与 Windows 兼容的文件名后，无法再修改现有文件，但可以由其所有者重命名为有效的新名称。",
+    "Failed to toggle Windows filename support" : "无法切换 Windows 文件名支持",
+    "Files compatibility" : "文件兼容性",
+    "Enforce Windows compatibility" : "强制 Windows 兼容性",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "这将阻止在 Windows 系统中无效的文件名称，比如使用保留字符。但这不会强制大小写敏感性兼容。",
     "You" : "您",
     "Shared multiple times with different people" : "与不同的用户多次分享",
+    "Unable to change the favorite state of the file" : "无法更改文件的收藏状态",
     "Error while loading the file data" : "加载文件数据时出错",
     "Owner" : "拥有者",
     "Remove from favorites" : "从收藏中移除",
-    "Add to favorites" : "添加到收藏夹",
+    "Add to favorites" : "添加到收藏",
     "Tags" : "标签",
     "Blank" : "空白",
     "Unable to create new file from template" : "无法从模板创建新文件",
@@ -243,7 +285,6 @@ OC.L10N.register(
     "File successfully converted" : "文件已成功转换",
     "Failed to convert file: {message}" : "无法转换文件：{message}",
     "Failed to convert file" : "无法转换文件",
-    "Deletion cancelled" : "已取消删除",
     "Leave this share" : "离开此共享",
     "Leave these shares" : "离开此分享",
     "Disconnect storage" : "断开与存储空间的连接",
@@ -254,39 +295,38 @@ OC.L10N.register(
     "Delete files" : "删除文件",
     "Delete folder" : "删除文件夹",
     "Delete folders" : "删除文件夹",
-    "Delete" : "删除",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您正要永久删除 {count} 个项目"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您正要删除 {count} 个项目"],
     "Confirm deletion" : "确认删除",
     "Cancel" : "取消",
+    "Download" : "下载",
+    "The requested file is not available." : "请求的文件不可用。",
+    "The requested files are not available." : "请求的文件不可用。",
     "Moving \"{source}\" to \"{destination}\" …" : "正在移动 “{source}” 至 “{destination}” ...",
     "Copying \"{source}\" to \"{destination}\" …" : "正在复制 “{source}” 至 “{destination}” ...",
+    "Destination is not a folder" : "目标不是一个文件夹",
+    "This file/folder is already in that directory" : "该文件/文件夹已经存在与该目录中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "你无法将文件/文件夹移动至其自身或子文件夹中",
     "(copy)" : "（复制）",
     "(copy %n)" : "(复制 %n)",
-    "Move cancelled" : "已取消移动",
     "A file or folder with that name already exists in this folder" : "相同的文件/文件夹已存在于该文件夹中",
     "The files are locked" : "文件已锁定",
     "The file does not exist anymore" : "文件不存在",
     "Choose destination" : "选择目标路径",
     "Copy to {target}" : "复制到 {target}",
-    "Copy" : "复制",
     "Move to {target}" : "移动到 {target}",
     "Move" : "移动",
     "Move or copy operation failed" : "移动或复制失败",
     "Move or copy" : "移动或复制",
-    "Cancelled move or copy of \"{filename}\"." : "取消移动或复制“{filename}”.",
-    "Cancelled move or copy operation" : "已取消移动或复制操作",
     "Open folder {displayName}" : "打开文件夹{displayName}",
     "Open in Files" : "在文件中打开",
+    "Open locally" : "本地打开",
+    "Failed to redirect to client" : "重定向到客户端失败",
     "Open file locally" : "在本地打开文件",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "该文件现在应该在你的设备上打开。如果没有，请检查你是否安装了桌面应用程序。",
     "Retry and close" : "重试并关闭",
     "Open online" : "在线打开",
-    "Failed to redirect to client" : "重定向到客户端失败",
-    "Open locally" : "本地打开",
-    "Rename" : "重命名",
-    "Open details" : "打开详情",
+    "Details" : "详细信息",
     "View in folder" : "在文件夹中查看",
     "Today" : "今日",
     "Last 7 days" : "过去 7 天",
@@ -299,15 +339,15 @@ OC.L10N.register(
     "PDFs" : "PDF",
     "Folders" : "文件夹",
     "Audio" : "音频",
-    "Photos and images" : "照片和图像",
+    "Images" : "图片",
     "Videos" : "视频",
-    "New folder creation cancelled" : "取消创建新文件夹",
     "Created new folder \"{name}\"" : "已创建新文件夹“{name}”",
     "Unable to initialize the templates directory" : "无法初始化模板目录",
     "Create templates folder" : "创建模板文件夹",
     "Templates" : "模板",
     "New template folder" : "新建模板文件夹",
     "In folder" : "文件夹内",
+    "Search in all files" : "在所有文件中搜索",
     "Search in folder: {folder}" : "在文件夹内搜索：{folder}",
     "One of the dropped files could not be processed" : "无法处理其中一个已删除的文件",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "你的浏览器不支持文件系统API。目录不会被上传",
@@ -316,21 +356,22 @@ OC.L10N.register(
     "Some files could not be uploaded" : "部分文件无法上传",
     "Files uploaded successfully" : "上传文件成功",
     "No files to process" : "没有需要处理的文件",
-    "Some files could not be copied" : "无法复制某些文件",
-    "Some files could not be moved" : "某些文件无法被移动",
+    "Some files could not be copied" : "无法复制部分文件",
+    "Some files could not be moved" : "无法移动部分文件",
     "Files copied successfully" : "复制文件成功",
     "Files moved successfully" : "移动文件成功",
     "Conflicts resolution skipped" : "已跳过冲突解决",
     "Upload cancelled" : "已取消上传",
+    "Could not rename \"{oldName}\", it does not exist any more" : "无法重命名“{oldName}”，此文件已经不存在",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名称“{newName}”在这个文件夹“{dir}”已经被使用。请选择其他名称。",
+    "Could not rename \"{oldName}\"" : "无法重命名“{oldName}”",
     "This operation is forbidden" : "该操作被禁止",
-    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
+    "This folder is unavailable, please try again later or contact the administration" : "此文件夹不可用，请稍后重试或联系管理员",
     "Storage is temporarily not available" : "存储空间暂时不可用",
     "Unexpected error: {error}" : "意外错误：{error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 个文件夹"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 个文件"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 个文件夹及 {folderCount} 个文件夹"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 个文件及 1 个文件夹"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} 个文件及 {folderCount} 个文件夹",
+    "_%n file_::_%n files_" : ["%n 个文件"],
+    "_%n folder_::_%n folders_" : ["%n 个文件夹"],
+    "_%n hidden_::_%n hidden_" : ["%n 已隐藏"],
     "Filename must not be empty." : "文件名不能为空。",
     "\"{char}\" is not allowed inside a filename." : "文件名中不允许出现 “{char}”",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "“{segment}” 是一个保留名称，不允许用在文件名中。",
@@ -339,10 +380,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "收藏的文件和文件夹列表。",
     "No favorites yet" : "暂无收藏",
     "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
-    "All files" : "全部文件",
     "List of your files and folders." : "您的文件与文件件列表。",
-    "All folders" : "所有文件夹",
-    "Personal files" : "个人文件",
     "List of your files and folders that are not shared." : "尚未分享的文件与文件夹",
     "No personal files found" : "找不到个人文件",
     "Files that are not shared will show up here." : "尚未分享的文件会显示在此处",
@@ -350,12 +388,13 @@ OC.L10N.register(
     "List of recently modified files and folders." : "最近修改的文件与文件夹列表。",
     "No recently modified files" : "近期无修改文件",
     "Files and folders you recently modified will show up here." : "你最近修改的文件与文件夹将会显示在此处。",
+    "Search" : "搜索",
+    "Search results within your files." : "在您的文件中搜索结果。",
     "No entries found in this folder" : "在此文件夹中找不到项目",
     "Select all" : "全部选择",
     "Upload too large" : "上传文件过大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您尝试上传的文件大小超过了服务器的限制。",
     "File could not be found" : "文件未找到",
-    "Download" : "下载",
     "Show list view" : "显示列表视图",
     "Show grid view" : "显示网格视图",
     "Close" : "关闭",
@@ -380,12 +419,12 @@ OC.L10N.register(
     "Edit locally" : "本地编辑",
     "Open" : "打开",
     "Could not load info for file \"{file}\"" : "无法加载文件“{file}”的信息",
-    "Details" : "详细信息",
     "Please select tag(s) to add to the selection" : "请选择要添加到所选项目的标签",
     "Apply tag(s) to selection" : "将标签应用到所选项目",
     "Select directory \"{dirName}\"" : "选择目录“{dirName}”",
     "Select file \"{fileName}\"" : "选择文件“{fileName}”",
     "Unable to determine date" : "无法确定日期",
+    "This directory is unavailable, please check the logs or contact the administrator" : "此目录不可用，请检查日志或联系管理员",
     "Could not move \"{file}\", target exists" : "无法移动“{file}”，目标已存在",
     "Could not move \"{file}\"" : "无法移动“{file}”",
     "copy" : "复制",
@@ -394,9 +433,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "在 {destination} 内复制 {origin}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "在 {destination} 内复制了 {origin} 和 {nbfiles} 个其他文件",
     "{newName} already exists" : "{newName} 已经存在",
-    "Could not rename \"{fileName}\", it does not exist any more" : "无法重命名“{fileName}”，此文件已经不存在",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "文件夹“{dir}”中已经存在“{targetName}”。请尝试其它名称。",
-    "Could not rename \"{fileName}\"" : "无法重命名“{fileName}”",
     "Could not create file \"{file}\"" : "无法创建文件“{file}”",
     "Could not create file \"{file}\" because it already exists" : "无法创建文件“{file}”，因为它已经存在",
     "Could not create folder \"{dir}\" because it already exists" : "无法创建文件夹“{dir}”，因为它已经存在",
@@ -404,8 +440,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "删除文件“{fileName}”时出错。",
     "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于 {tag}{filter}{endtag} 的搜索结果",
     "Enter more than two characters to search in other folders" : "输入至少三个字符，以搜索其他文件夹",
-    "_%n folder_::_%n folders_" : ["%n 个文件夹"],
-    "_%n file_::_%n files_" : ["%n 个文件"],
     "{dirs} and {files}" : "{dirs} 和 {files}",
     "_including %n hidden_::_including %n hidden_" : ["包括 %n 个隐藏文件"],
     "You do not have permission to upload or create files here" : "您没有在此上传或创建文件的权限",
@@ -431,30 +465,63 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "已复制直接链接（仅适用于有权访问此文件/文件夹的用户）",
     "Path" : "路径",
     "_%n byte_::_%n bytes_" : ["%n 字节"],
-    "Favorited" : "已收藏",
+    "Favored" : "已加入收藏",
+    "Favor" : "收藏",
     "Copy direct link (only works for people who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
     "Upload file" : "上传文件",
-    "Not favorited" : "未收藏",
+    "Not favored" : "未收藏",
     "An error occurred while trying to update the tags" : "更新标签时出错",
-    "You don't have permission to upload or create files here." : "您没有在此处上传或创建文件的权限。",
-    "Storage informations" : "存储信息",
-    "Choose file" : "选择文件",
-    "Go to the previous folder" : "回到前一个文件夹",
-    "Open the files app settings" : "打开文件设置",
-    "Unable to change the favourite state of the file" : "无法修改文件的收藏状态",
-    "Edit file locally" : "本地编辑",
-    "Edit online" : "在线编辑",
-    "Create new templates folder" : "新建模板文件夹",
-    "List of favorites files and folders." : "收藏文件和文件夹列表",
+    "Upload (max. %s)" : "上传 （最大 %s）",
+    "\"{displayName}\" action executed successfully" : "“{displayName}”操作执行成功",
+    "\"{displayName}\" action failed" : "“{displayName}”操作执行失败",
+    "\"{displayName}\" failed on some elements" : "“{displayName}”在部分元素上失败",
+    "\"{displayName}\" batch action executed successfully" : "批量操作“{displayName}”运行成功",
+    "Submitting fields…" : "提交字段...",
+    "Filter filenames…" : "过滤文件名...",
+    "WebDAV URL copied to clipboard" : "WebDAV 链接已复制到剪贴板",
+    "Enable the grid view" : "启用网格视图",
+    "Enable folder tree" : "启用文件夹树",
+    "Copy to clipboard" : "复制到剪贴板",
+    "Use this address to access your Files via WebDAV" : "使用此地址通过 WebDAV 访问您的文件",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果启用两步验证，您必须点击此处来创建和使用一个新的应用程序密码。",
+    "Deletion cancelled" : "已取消删除",
+    "Move cancelled" : "已取消移动",
+    "Cancelled move or copy of \"{filename}\"." : "取消移动或复制“{filename}”.",
+    "Cancelled move or copy operation" : "已取消移动或复制操作",
+    "Open details" : "打开详情",
+    "Photos and images" : "照片和图像",
+    "New folder creation cancelled" : "取消创建新文件夹",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 个文件夹"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 个文件"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 个文件夹及 {folderCount} 个文件夹"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 个文件及 1 个文件夹"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} 个文件及 {folderCount} 个文件夹",
+    "All folders" : "所有文件夹",
     "Personal Files" : "个人文件",
     "Text file" : "文本文件",
     "New text file.txt" : "新建文本文件.txt",
-    "Favored" : "已加入收藏",
-    "Favor" : "收藏",
-    "Not favored" : "未收藏",
-    "Submitting fields…" : "提交字段...",
-    "Filter filenames…" : "过滤文件名...",
-    "{count} files could not be converted" : "{count} 个文件无法转换",
-    "{count} files successfully converted" : "{count} 个文件已成功转换"
+    "%1$s (renamed)" : "%1$s（已重命名）",
+    "renamed file" : "已重命名文件",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "启用与 Windows 兼容的文件名后，无法再修改现有文件，但可以由其所有者重命名为有效的新名称。",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "启用此设置后，也可以自动迁移文件，请参阅有关 occ 命令的文档。",
+    "Filter file names …" : "筛选文件名…",
+    "Prevent warning dialogs from open or reenable them." : "防止打开或重新启用警告对话框。",
+    "Show a warning dialog when changing a file extension." : "更改文件扩展名时显示警告对话框。",
+    "Speed up your Files experience with these quick shortcuts." : "这些快捷键可以加快你的“文件”体验。",
+    "Open the actions menu for a file" : "打开文件的操作菜单",
+    "Rename a file" : "重命名文件",
+    "Delete a file" : "删除文件",
+    "Favorite or remove a file from favorites" : "把文件添加或移除出收藏夹",
+    "Manage tags for a file" : "管理文件的标签",
+    "Deselect all files" : "取消选择所有文件",
+    "Select or deselect a file" : "选择或取消选择文件",
+    "Select a range of files" : "选择一系列文件",
+    "Navigate to the parent folder" : "前往上一级文件夹",
+    "Navigate to the file above" : "跳转至以上文件",
+    "Navigate to the file below" : "跳转至以下文件",
+    "Navigate to the file on the left (in grid mode)" : "跳转至左侧文件（在网格模式下）",
+    "Navigate to the file on the right (in grid mode)" : "跳转至右侧文件（在网格模式下）",
+    "Toggle the grid view" : "切换网格视图",
+    "Open the sidebar for a file" : "在侧边栏打开文件"
 },
 "nplurals=1; plural=0;");
