@@ -2,11 +2,11 @@ OC.L10N.register(
     "files_external",
     {
     "Grant access" : "Salli pääsy",
-    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
-    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
     "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
     "Generate keys" : "Luo avaimet",
     "Error generating key pair" : "Virhe luotaessa avainparia",
+    "You are not logged in" : "Et ole kirjautuneena sisään",
+    "Permission denied" : "Ei käyttöoikeutta",
     "Storage with ID \"%d\" not found" : "Tallennustilaa tunnisteella \"%d\" ei löytynyt",
     "Invalid backend or authentication mechanism class" : "Virheellinen tietovarasto tai tunnistautumismekanismin luokka",
     "Invalid mount point" : "Virheellinen liitoskohta",
@@ -22,9 +22,6 @@ OC.L10N.register(
     "Secret key" : "Salainen avain",
     "Builtin" : "Sisäänrakennettu",
     "None" : "Ei mitään",
-    "OAuth1" : "OAuth1",
-    "App key" : "Sovellusavain",
-    "App secret" : "Sovellussalaisuus",
     "OAuth2" : "OAuth2",
     "Client ID" : "Asiakkaan tunniste",
     "Client secret" : "Asiakassalaisuus",
@@ -81,7 +78,7 @@ OC.L10N.register(
     "External storage" : "Erillinen tallennustila",
     "External storage support" : "Erillisen tallennustilan tuki",
     "Adds basic external storage support" : "Lisää perusmuotoisen tuen erillisille tallennustiloille",
-    "Submit" : "Lähetä",
+    "Confirm" : "Vahvista",
     "Open in Files" : "Avaa tiedostosovelluksessa",
     "External mount error" : "Erillisen liitosvirhe",
     "Storage type" : "Tallennustilan tyyppi",
@@ -113,7 +110,13 @@ OC.L10N.register(
     "Configuration" : "Asetukset",
     "Available for" : "Saatavuus",
     "Add storage" : "Lisää tallennustila",
+    "All people" : "Kaikki ihmiset",
     "Advanced settings" : "Lisäasetukset",
-    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Yleisiä tunnistetietoja voidaan käyttää useisiin ulkoisiin tallennustiloihin tunnistautumiseen, joissa käytetään samoja tunnistetietoja."
+    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Yleisiä tunnistetietoja voidaan käyttää useisiin ulkoisiin tallennustiloihin tunnistautumiseen, joissa käytetään samoja tunnistetietoja.",
+    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
+    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
+    "OAuth1" : "OAuth1",
+    "App key" : "Sovellusavain",
+    "App secret" : "Sovellussalaisuus"
 },
 "nplurals=2; plural=(n != 1);");
