@@ -11,10 +11,13 @@ OC.L10N.register(
     "Name" : "Název",
     "Redirection URI" : "URL pro přesměrování",
     "Client Identifier" : "Identifikátor klienta",
-    "Secret" : "Tajemství",
+    "Secret key" : "Tajný klíč",
+    "Delete client" : "Smazat klienta",
+    "Make sure you store the secret key, it cannot be recovered." : "Nezapomeňte si uložit tajný klíč – není možné ho obnovit.",
     "Add client" : "Přidat klienta",
     "Add" : "Přidat",
     "Show client secret" : "Zobrazit klientské tajemství",
+    "Hide client secret" : "Skrýt tajemství klienta",
     "Delete" : "Smazat"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
