@@ -200,8 +200,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI video",
-    "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Podrobnosti naleznete v {linkstart}dokumentaci ↗{linkend}.",
     "unknown text" : "neznámý text",
     "Hello world!" : "Dobrý den světe!",
     "sunny" : "slunečno",
@@ -230,7 +228,7 @@ OC.L10N.register(
     "Federated user" : "Federovaný uživatel",
     "user@your-nextcloud.org" : "uzivatel@vas-nextcloud.org",
     "Create share" : "Vytvořit sdílení",
-    "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky",
+    "Direct link copied" : "Přímý odkaz zkopírován",
     "Please copy the link manually:" : "Zkopírujte odkaz ručně:",
     "Custom date range" : "Uživatelsky určené datumové rozmezí",
     "Pick start date" : "Vybrat datum začátku",
@@ -247,6 +245,7 @@ OC.L10N.register(
     "Last 30 days" : "Uplynulých 30 dnů",
     "This year" : "Tento rok",
     "Last year" : "Uplynulý rok",
+    "Between {startDate} and {endDate}" : "Mezi {startDate} a {endDate}",
     "Unified search" : "Sjednocené vyhledávání",
     "Search apps, files, tags, messages" : "Prohledat aplikace, soubory, štítky a zprávy",
     "Places" : "Místa",
@@ -254,6 +253,7 @@ OC.L10N.register(
     "Search people" : "Hledat osoby",
     "People" : "Lidé",
     "Filter in current view" : "Filtrovat ve stávajícím pohledu",
+    "Search connected services" : "Hledat připojené služby",
     "Results" : "Výsledky",
     "Load more results" : "Načíst další výsledky",
     "Search in" : "Hledat v",
@@ -329,7 +329,7 @@ OC.L10N.register(
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Přihlašovací formulář je v Nextcloud vypnutý. Použijte jinou možnost přihlášení nebo se obraťte na svého správce.",
     "More actions" : "Další akce",
     "User menu" : "Nabídka uživatele",
-    "You will be identified as {user} by the account owner." : "Vlastníkem účtu budete identifikováni jako {user}.",
+    "Your guest name: {user}" : "Vaše jméno, coby hosta: {user}",
     "You are currently not identified." : "V tuto chvíli nejste identifikováni.",
     "Set public name" : "Nastavit veřejné jméno",
     "Change public name" : "Změnit veřejné jméno",
@@ -505,6 +505,8 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Tato instance %s se právě nachází v režimu údržby a ta může chvíli trvat.",
     "This page will refresh itself when the instance is available again." : "Tato stránka se automaticky znovu načte, jakmile bude tato instance opět dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Pokud se tato zpráva objevuje trvale nebo nečekaně, obraťte se na správce systému.",
+    "Error occurred while checking server setup" : "Při ověřování nastavení serveru došlo k chybě",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Podrobnosti naleznete v {linkstart}dokumentaci ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatování, videohovory, sdílení obrazovky, schůze na dálku a webové konference – ve webovém prohlížeči a mobilních aplikacích.",
     "You have not added any info yet" : "Zatím jste nezadali žádné informace",
     "{user} has not added any info yet" : "{user} uživatel zatím nezadal žádné informace",
@@ -527,6 +529,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Přepnout viditelnost hesla",
     "Configure the database" : "Nastavit databázi",
     "Only %s is available." : "Je k dispozici pouze %s.",
-    "Database account" : "Účet do databáze"
+    "Database account" : "Účet do databáze",
+    "Direct link copied to clipboard" : "Přímý odkaz zkopírován do schránky"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
