@@ -200,8 +200,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI video",
-    "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
     "unknown text" : "unknown text",
     "Hello world!" : "Hello world!",
     "sunny" : "sunny",
@@ -230,7 +228,7 @@ OC.L10N.register(
     "Federated user" : "Federated user",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Create share",
-    "Direct link copied to clipboard" : "Direct link copied to clipboard",
+    "Direct link copied" : "Direct link copied",
     "Please copy the link manually:" : "Please copy the link manually:",
     "Custom date range" : "Custom date range",
     "Pick start date" : "Pick start date",
@@ -247,6 +245,7 @@ OC.L10N.register(
     "Last 30 days" : "Last 30 days",
     "This year" : "This year",
     "Last year" : "Last year",
+    "Between {startDate} and {endDate}" : "Between {startDate} and {endDate}",
     "Unified search" : "Unified search",
     "Search apps, files, tags, messages" : "Search apps, files, tags, messages",
     "Places" : "Places",
@@ -254,6 +253,7 @@ OC.L10N.register(
     "Search people" : "Search people",
     "People" : "People",
     "Filter in current view" : "Filter in current view",
+    "Search connected services" : "Search connected services",
     "Results" : "Results",
     "Load more results" : "Load more results",
     "Search in" : "Search in",
@@ -328,6 +328,11 @@ OC.L10N.register(
     "Login form is disabled." : "Login form is disabled.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "The Nextcloud login form is disabled. Use another login option if available or contact your administration.",
     "More actions" : "More actions",
+    "User menu" : "User menu",
+    "Your guest name: {user}" : "Your guest name: {user}",
+    "You are currently not identified." : "You are currently not identified.",
+    "Set public name" : "Set public name",
+    "Change public name" : "Change public name",
     "Password is too weak" : "Password is too weak",
     "Password is weak" : "Password is weak",
     "Password is average" : "Password is average",
@@ -421,6 +426,7 @@ OC.L10N.register(
     "Admin" : "Admin",
     "Help" : "Help",
     "Access forbidden" : "Access denied",
+    "You are not allowed to access this page." : "You are not allowed to access this page.",
     "Back to %s" : "Back to %s",
     "Page not found" : "Page not found",
     "The page could not be found on the server or you may not be allowed to view it." : "The page could not be found on the server or you may not be allowed to view it.",
@@ -499,6 +505,8 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
+    "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
     "You have not added any info yet" : "You have not added any info yet",
     "{user} has not added any info yet" : "{user} has not added any info yet",
@@ -521,6 +529,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Toggle password visibility",
     "Configure the database" : "Configure the database",
     "Only %s is available." : "Only %s is available.",
-    "Database account" : "Database account"
+    "Database account" : "Database account",
+    "Direct link copied to clipboard" : "Direct link copied to clipboard"
 },
 "nplurals=2; plural=(n != 1);");
