@@ -200,8 +200,6 @@ OC.L10N.register(
     "Matroska video" : "Vídeo Matroska",
     "Windows Media video" : "Vídeo Windows Media",
     "AVI video" : "Vídeo AVI",
-    "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter mais detalhes, consulte a {linkstart}documentação ↗{linkend}.",
     "unknown text" : "texto desconhecido",
     "Hello world!" : "Olá mundo!",
     "sunny" : "ensolarado",
@@ -230,7 +228,7 @@ OC.L10N.register(
     "Federated user" : "Usuário federado",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Criar compartilhamento",
-    "Direct link copied to clipboard" : "Link direto copiado para a área de transferência",
+    "Direct link copied" : "Link direto copiado",
     "Please copy the link manually:" : "Copie o link manualmente:",
     "Custom date range" : "Intervalo personalizado",
     "Pick start date" : "Escolha uma data de início",
@@ -247,6 +245,7 @@ OC.L10N.register(
     "Last 30 days" : "Últimos 30 dias",
     "This year" : "Este ano",
     "Last year" : "Último ano",
+    "Between {startDate} and {endDate}" : "Entre {startDate} e {endDate}",
     "Unified search" : "Pesquisa unificada",
     "Search apps, files, tags, messages" : "Pesquise aplicativos, arquivos, etiquetas, mensagens",
     "Places" : "Lugares",
@@ -254,6 +253,7 @@ OC.L10N.register(
     "Search people" : "Pesquise pessoas",
     "People" : "Pessoas",
     "Filter in current view" : "Filtrar na visualização atual",
+    "Search connected services" : "Pesquisar serviços conectados",
     "Results" : "Resultados",
     "Load more results" : "Carregar mais resultados",
     "Search in" : "Pesquisar em",
@@ -328,6 +328,11 @@ OC.L10N.register(
     "Login form is disabled." : "O formulário de login está desativado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulário de login do Nextcloud está desabilitado. Use outra opção de login, se disponível, ou entre em contato com sua administração.",
     "More actions" : "Mais ações",
+    "User menu" : "Menu do usuário",
+    "Your guest name: {user}" : "Seu nome de convidado: {user}",
+    "You are currently not identified." : "No momento, você não está identificado.",
+    "Set public name" : "Definir nome público",
+    "Change public name" : "Mudar nome público",
     "Password is too weak" : "A senha é muito fraca",
     "Password is weak" : "A senha é fraca",
     "Password is average" : "A senha é média",
@@ -421,6 +426,7 @@ OC.L10N.register(
     "Admin" : "Administração",
     "Help" : "Ajuda",
     "Access forbidden" : "Acesso proibido",
+    "You are not allowed to access this page." : "Você não tem permissão para acessar esta página.",
     "Back to %s" : "Voltar para %s",
     "Page not found" : "Página não encontrada",
     "The page could not be found on the server or you may not be allowed to view it." : "A página não pôde ser encontrada no servidor ou talvez você não tenha permissão para visualizá-la.",
@@ -499,6 +505,8 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
     "This page will refresh itself when the instance is available again." : "Esta página será atualizada quando o Nextcloud estiver disponível novamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Entre em contato com o administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
+    "Error occurred while checking server setup" : "Erro ao verificar a configuração do servidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter mais detalhes, consulte a {linkstart}documentação ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Bate-papo, vídeo chamadas, compartilhamento de tela, reuniões on-line e conferência na web - no seu navegador e com aplicativos móveis.",
     "You have not added any info yet" : "Você ainda não adicionou nenhuma informação",
     "{user} has not added any info yet" : "{user} ainda não adicionou nenhuma informação",
@@ -521,6 +529,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Alternar visibilidade da senha",
     "Configure the database" : "Configurar o banco de dados",
     "Only %s is available." : "Somente %s está disponível.",
-    "Database account" : "Conta de banco de dados"
+    "Database account" : "Conta de banco de dados",
+    "Direct link copied to clipboard" : "Link direto copiado para a área de transferência"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
