@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "嘗試登入時發生錯誤",
     "State token missing" : "狀態代符遺失",
     "Your login token is invalid or has expired" : "您的登入代符無效或已過期",
+    "Please use original client" : "請使用原始客戶端",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "這個 Nextcloud 的社群版本沒有得到支援，而且推播通知會有所限制。",
     "Login" : "登入",
     "Unsupported email length (>255)" : "不支援的電子郵件長度 (>255)",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "Task not found" : "找不到任務",
     "Internal error" : "內部錯誤",
     "Not found" : "找不到",
+    "Node is locked" : "節點已鎖定",
     "Bad request" : "錯誤的請求",
     "Requested task type does not exist" : "請求的任務類型不存在",
     "Necessary language model provider is not available" : "沒有可用的語言模型程式",
@@ -51,6 +53,11 @@ OC.L10N.register(
     "No translation provider available" : "沒有可用的翻譯提供者",
     "Could not detect language" : "無法偵測語言",
     "Unable to translate" : "無法翻譯",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "修復步驟：",
+    "Repair info:" : "修復資訊：",
+    "Repair warning:" : "修復警告：",
+    "Repair error:" : "修復錯誤：",
     "Nextcloud Server" : "Nextcloud 伺服器",
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "出於安全性問題，我們必須移除您一部分的分享連結。查看更多資訊請點選連結。",
@@ -58,11 +65,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加帳號限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
     "Learn more ↗" : "深入瞭解 ↗",
     "Preparing update" : "準備更新",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "修復步驟：",
-    "Repair info:" : "修復資訊：",
-    "Repair warning:" : "修復警告：",
-    "Repair error:" : "修復錯誤：",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。",
     "Turned on maintenance mode" : "啟用維護模式",
     "Turned off maintenance mode" : "停用維護模式",
@@ -79,8 +81,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s（不相容）",
     "The following apps have been disabled: %s" : "以下應用程式已被停用：%s",
     "Already up to date" : "已是最新版本",
-    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "詳細資訊請參閱 {linkstart} 文件 ↗{linkend}。",
+    "Windows Command Script" : "Windows 命令稿",
+    "Electronic book document" : "電子書文件",
+    "TrueType Font Collection" : "TrueType 字型集合",
+    "Web Open Font Format" : "Web 開放字型格式",
+    "GPX geographic data" : "GPX 地理資料",
+    "Gzip archive" : "Gzip 封存檔",
+    "Adobe Illustrator document" : "Adobe Illustrator 文件",
+    "Java source code" : "Java 原始碼",
+    "JavaScript source code" : "JavaScript 原始碼",
+    "JSON document" : "JSON 文件",
+    "Microsoft Access database" : "Microsoft Access 資料庫",
+    "Microsoft OneNote document" : "Microsoft OneNote 文件",
+    "Microsoft Word document" : "Microsoft Word 文件",
+    "Unknown" : "未知",
+    "PDF document" : "PDF 文件",
+    "PostScript document" : "PostScript 文件",
+    "RSS summary" : "RSS 摘要",
+    "Android package" : "Android 軟體包",
+    "KML geographic data" : "KML 地理資料",
+    "KML geographic compressed data" : "KML 地理壓縮資料",
+    "Lotus Word Pro document" : "Lotus Word Pro 文件",
+    "Excel spreadsheet" : "Excel 試算表",
+    "Excel add-in" : "Excel 增益集",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 二進位試算表",
+    "Excel spreadsheet template" : "Excel 試算表範本",
+    "Outlook Message" : "Outlook 訊息",
+    "PowerPoint presentation" : "PowerPoint 簡報",
+    "PowerPoint add-in" : "PowerPoint 增益集",
+    "PowerPoint presentation template" : "PowerPoint 簡報範本",
+    "Word document" : "Word 文件",
+    "ODF formula" : "ODF 公式",
+    "ODG drawing" : "ODG 繪圖",
+    "ODG drawing (Flat XML)" : "ODG 繪圖 (Flat XML)",
+    "ODG template" : "ODG 範本",
+    "ODP presentation" : "ODP 簡報",
+    "ODP presentation (Flat XML)" : "ODP 簡報 (Flat XML)",
+    "ODP template" : "ODP 範本",
+    "ODS spreadsheet" : "ODS 試算表",
+    "ODS spreadsheet (Flat XML)" : "ODS 試算表 (Flat XML)",
+    "ODS template" : "ODS 範本",
+    "ODT document" : "ODT 文件",
+    "ODT document (Flat XML)" : "ODT 文件 (Flat XML)",
+    "ODT template" : "ODT 範本",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 簡報",
+    "PowerPoint 2007 show" : "PowerPoint 2007 自動放映",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 簡報範本",
+    "Excel 2007 spreadsheet" : "Excel 2007 試算表",
+    "Excel 2007 spreadsheet template" : "Excel 2007 試算表範本",
+    "Word 2007 document" : "Word 2007 文件",
+    "Word 2007 document template" : "Word 2007 文件範本",
+    "Microsoft Visio document" : "Microsoft Visio 文件",
+    "WordPerfect document" : "WordPerfect 文件",
+    "7-zip archive" : "7-zip 封存檔",
+    "Blender scene" : "Blender 場景",
+    "Bzip2 archive" : "Bzip2 封存檔",
+    "Debian package" : "Debian 軟體包",
+    "FictionBook document" : "FictionBook 文件",
+    "Unknown font" : "未知字型",
+    "Krita document" : "Krita 文件",
+    "Mobipocket e-book" : "Mobipocket 電子書",
+    "Windows Installer package" : "Windows 安裝程式包",
+    "Perl script" : "Perl 命令稿",
+    "PHP script" : "PHP 命令稿",
+    "Tar archive" : "Tar 封存檔",
+    "XML document" : "XML 文件",
+    "YAML document" : "YAML 文件",
+    "Zip archive" : "Zip 封存檔",
+    "Zstandard archive" : "Zstandard 封存檔",
+    "AAC audio" : "AAC 音訊",
+    "FLAC audio" : "FLAC 音訊",
+    "MPEG-4 audio" : "MPEG-4 音訊",
+    "MP3 audio" : "MP3 音訊",
+    "Ogg audio" : "Ogg 音訊",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe 標準音訊",
+    "WebM audio" : "WebM 音訊",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast 播放清單",
+    "Windows BMP image" : "Windows BMP 影像",
+    "Better Portable Graphics image" : "BPG 影像",
+    "EMF image" : "EMF 影像",
+    "GIF image" : "GIF 影像",
+    "HEIC image" : "HEIC 影像",
+    "HEIF image" : "HEIF 影像",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 影像",
+    "JPEG image" : "JPEG 影像",
+    "PNG image" : "PNG 圖檔",
+    "SVG image" : "SVG 影像",
+    "Truevision Targa image" : "Truevision Targa 影像",
+    "TIFF image" : "TIFF 影像",
+    "WebP image" : "WebP 影像",
+    "Digital raw image" : "數位原始影像",
+    "Windows Icon" : "Windows 圖示",
+    "Email message" : "電子郵件訊息",
+    "VCS/ICS calendar" : "VCS/ICS 行事曆",
+    "CSS stylesheet" : "CSS 樣式表",
+    "CSV document" : "CSV 文件",
+    "HTML document" : "HTML 文件",
+    "Markdown document" : "Markdown 文件",
+    "Org-mode file" : "Org-mode 檔案",
+    "Plain text document" : "純文字文件",
+    "Rich Text document" : "RTF 文件",
+    "Electronic business card" : "電子名片",
+    "C++ source code" : "C++ 原始碼",
+    "LDIF address book" : "LDIF 通訊錄",
+    "NFO document" : "NFO 文件",
+    "PHP source" : "PHP 原始碼",
+    "Python script" : "Python 命令稿",
+    "ReStructuredText document" : "ReStructuredText 文件",
+    "3GPP multimedia file" : "3GPP 多媒體檔案",
+    "MPEG video" : "MPEG 視訊",
+    "DV video" : "DV 視訊",
+    "MPEG-2 transport stream" : "MPEG2 傳輸串流",
+    "MPEG-4 video" : "MPEG-4 視訊",
+    "Ogg video" : "Ogg 視訊",
+    "QuickTime video" : "QuickTime 視訊",
+    "WebM video" : "WebM 視訊",
+    "Flash video" : "Flash 視訊",
+    "Matroska video" : "Matroska 視訊",
+    "Windows Media video" : "Windows 媒體視訊",
+    "AVI video" : "AVI 視訊",
     "unknown text" : "未知的文字",
     "Hello world!" : "哈囉，世界！",
     "sunny" : "晴朗",
@@ -103,13 +222,13 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
     "No" : "否",
     "Yes" : "是",
-    "Federated user" : "聯盟使用者",
-    "user@your-nextcloud.org" : "user@your-nextcloud.org",
-    "Create share" : "建立分享",
     "The remote URL must include the user." : "遠端 URL 必須包含使用者。",
     "Invalid remote URL." : "無效的遠端 URL。",
     "Failed to add the public link to your Nextcloud" : "無法將公開連結新增到您的 Nextcloud",
-    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿",
+    "Federated user" : "聯盟使用者",
+    "user@your-nextcloud.org" : "user@your-nextcloud.org",
+    "Create share" : "建立分享",
+    "Direct link copied" : "已複製直接連結",
     "Please copy the link manually:" : "請手動複製連結：",
     "Custom date range" : "自訂日期範圍",
     "Pick start date" : "挑選開始日期",
@@ -118,56 +237,63 @@ OC.L10N.register(
     "Search in current app" : "在目前的應用程式中搜尋",
     "Clear search" : "清除搜尋",
     "Search everywhere" : "到處搜尋",
-    "Unified search" : "統一搜尋",
-    "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
-    "Places" : "地點",
-    "Date" : "日期",
+    "Searching …" : "正在搜尋…",
+    "Start typing to search" : "開始輸入以搜尋",
+    "No matching results" : "無相符結果",
     "Today" : "今天",
     "Last 7 days" : "過去 7 天",
     "Last 30 days" : "過去 30 天",
     "This year" : "今年",
     "Last year" : "去年",
+    "Between {startDate} and {endDate}" : "在 {startDate} 至 {endDate} 間",
+    "Unified search" : "統一搜尋",
+    "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
+    "Places" : "地點",
+    "Date" : "日期",
     "Search people" : "搜尋人物",
     "People" : "人物",
     "Filter in current view" : "目前檢視中的篩選條件",
+    "Search connected services" : "搜尋已連結的服務",
     "Results" : "結果",
     "Load more results" : "載入更多結果",
     "Search in" : "搜尋條件",
-    "Searching …" : "正在搜尋…",
-    "Start typing to search" : "開始輸入以搜尋",
-    "No matching results" : "無相符結果",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "介於 ${this.dateFilter.startFrom.toLocaleDateString()} 和 ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "登入",
     "Logging in …" : "正在登入…",
-    "Server side authentication failed!" : "伺服器端認證失敗！",
-    "Please contact your administrator." : "請聯絡系統管理員。",
-    "Temporary error" : "暫時錯誤",
-    "Please try again." : "請再試一次。",
-    "An internal error occurred." : "發生內部錯誤。",
-    "Please try again or contact your administrator." : "請重試，或聯絡您的系統管理員。",
-    "Password" : "密碼",
     "Log in to {productName}" : "登入 {productName}",
     "Wrong login or password." : "錯誤的帳號或密碼。",
     "This account is disabled" : "此帳號已停用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時 30 秒。",
     "Account name or email" : "帳號名稱或電子郵件",
     "Account name" : "帳號名稱",
+    "Server side authentication failed!" : "伺服器端認證失敗！",
+    "Please contact your administrator." : "請聯絡系統管理員。",
+    "Session error" : "工作階段錯誤",
+    "It appears your session token has expired, please refresh the page and try again." : "您的工作階段權杖似乎已過期，請重新整理頁面並重試。",
+    "An internal error occurred." : "發生內部錯誤。",
+    "Please try again or contact your administrator." : "請重試，或聯絡您的系統管理員。",
+    "Password" : "密碼",
     "Log in with a device" : "使用裝置登入",
     "Login or email" : "帳號或電子郵件",
     "Your account is not setup for passwordless login." : "您的帳號尚未設定無密碼登入。",
-    "Browser not supported" : "瀏覽器不支援",
-    "Passwordless authentication is not supported in your browser." : "您使用的瀏覽器不支援無密碼身份認證。",
     "Your connection is not secure" : "您的連線不安全",
     "Passwordless authentication is only available over a secure connection." : "無密碼身份認證僅可用於經加密的安全連線。",
+    "Browser not supported" : "瀏覽器不支援",
+    "Passwordless authentication is not supported in your browser." : "您使用的瀏覽器不支援無密碼身份認證。",
     "Reset password" : "重設密碼",
+    "Back to login" : "返回登入畫面",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "若此帳號存在，密碼重設郵件即已寄送至其電子郵件地址。若您未收到，請驗證您的電子郵件地址及/或帳號，並檢查您的垃圾郵件資料夾，或向您的本機管理員求助。",
     "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼資訊。請聯絡您的管理員。",
     "Password cannot be changed. Please contact your administrator." : "密碼無法變更。請聯絡您的管理員。",
-    "Back to login" : "返回登入畫面",
     "New password" : "新密碼",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "由於您已啟用檔案加密，重設密碼後，您的資料將無法解密。若您不確定繼續與否，請聯絡管理員。確定要繼續嗎？",
     "I know what I'm doing" : "我知道我在做什麼",
     "Resetting password" : "重設密碼",
+    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步。",
+    "Keep your colleagues and friends in one place without leaking their private info." : "在同一處聯繫您的同事和朋友，而不會洩漏他們的私人資訊。",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽、聯絡人、行事曆完美整合。",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議、網路研討會等 - 在您的瀏覽器與手機應用程式之中實現。",
+    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "使用 Collabora Online 建置的文件、試算表、簡報協作工具。",
+    "Distraction free note taking app." : "無干擾的筆記應用程式。",
     "Recommended apps" : "推薦的應用程式",
     "Loading apps …" : "正在載入應用程式…",
     "Could not fetch list of apps from the App Store." : "無法從應用程式商店擷取應用程式清單。",
@@ -177,14 +303,10 @@ OC.L10N.register(
     "Skip" : "跳過",
     "Installing apps …" : "正在安裝應用程式…",
     "Install recommended apps" : "安裝推薦的應用程式",
-    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步。",
-    "Keep your colleagues and friends in one place without leaking their private info." : "在同一處聯繫您的同事和朋友，而不會洩漏他們的私人資訊。",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽、聯絡人、行事曆完美整合。",
-    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議、網路研討會等 - 在您的瀏覽器與手機應用程式之中實現。",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "使用 Collabora Online 建置的文件、試算表、簡報協作工具。",
-    "Distraction free note taking app." : "無干擾的筆記應用程式。",
-    "Settings menu" : "設定選單",
     "Avatar of {displayName}" : "{displayName} 的頭像",
+    "Settings menu" : "設定選單",
+    "Loading your contacts …" : "正在載入聯絡人…",
+    "Looking for {term} …" : "正在搜尋 {term}…",
     "Search contacts" : "搜尋聯絡人",
     "Reset search" : "重設搜尋",
     "Search contacts …" : "搜尋聯絡人…",
@@ -192,26 +314,66 @@ OC.L10N.register(
     "No contacts found" : "查無聯絡人",
     "Show all contacts" : "顯示所有聯絡人",
     "Install the Contacts app" : "安裝「聯絡人」應用程式",
-    "Loading your contacts …" : "正在載入聯絡人…",
-    "Looking for {term} …" : "正在搜尋 {term}…",
-    "Search starts once you start typing and results may be reached with the arrow keys" : "您一開始輸入，搜尋就會開始，可以使用方向鍵切換搜尋結果",
-    "Search for {name} only" : "僅搜尋 {name}",
-    "Loading more results …" : "正在載入更多結果…",
     "Search" : "搜尋",
     "No results for {query}" : "{query} 查詢沒有結果",
     "Press Enter to start searching" : "按 Enter 開始搜尋",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "您一開始輸入，搜尋就會開始，可以使用方向鍵切換搜尋結果",
+    "Search for {name} only" : "僅搜尋 {name}",
+    "Loading more results …" : "正在載入更多結果…",
     "Forgot password?" : "忘記密碼？",
     "Back to login form" : "返回登入表單",
     "Back" : "返回",
     "Login form is disabled." : "登入表單已停用。",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
     "More actions" : "更多動作",
+    "User menu" : "使用者選單",
+    "Your guest name: {user}" : "您的訪客名稱：{user}",
+    "You are currently not identified." : "目前無法辨識您的身份。",
+    "Set public name" : "設定公開名稱",
+    "Change public name" : "變更公開名稱",
+    "Password is too weak" : "非常弱密碼",
+    "Password is weak" : "弱密碼",
+    "Password is average" : "一般密碼",
+    "Password is strong" : "強密碼",
+    "Password is very strong" : "非常強密碼",
+    "Password is extremely strong" : "極弱密碼",
+    "Unknown password strength" : "未知密碼強度",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 <code>.htaccess</code> 檔案並未生效。",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "{linkStart}閱讀說明文件{linkEnd}來瞭解如何正確設定您的伺服器",
+    "Autoconfig file detected" : "偵測到自動組態檔案",
+    "The setup form below is pre-filled with the values from the config file." : "下面的設定表單已預先填入設定檔中的值。",
+    "Security warning" : "安全性警告",
+    "Create administration account" : "建立管理員帳號",
+    "Administration account name" : "管理員帳號名稱",
+    "Administration account password" : "管理員帳號密碼",
+    "Storage & database" : "儲存空間和資料庫",
+    "Data folder" : "資料儲存位置",
+    "Database configuration" : "資料庫組態",
+    "Only {firstAndOnlyDatabase} is available." : "僅 {firstAndOnlyDatabase} 可用。",
+    "Install and activate additional PHP modules to choose other database types." : "安裝並啟用相關 PHP 模組來選擇其他資料庫類型。",
+    "For more details check out the documentation." : "請參閱說明文件了解更多細節。",
+    "Performance warning" : "效能警告",
+    "You chose SQLite as database." : "您選擇了 SQLite 作為資料庫。",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或開發中站台。對於正式上線用途，我們建議改用其他資料庫後端。",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若您會使用桌面版或手機版客戶端同步檔案，則強烈不建議使用 SQLite。",
+    "Database user" : "資料庫使用者",
+    "Database password" : "資料庫密碼",
+    "Database name" : "資料庫名稱",
+    "Database tablespace" : "資料庫資料表空間",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
+    "Database host" : "資料庫主機",
+    "localhost" : "localhost",
+    "Installing …" : "正在安裝…",
+    "Install" : "安裝",
+    "Need help?" : "需要協助嗎？",
+    "See the documentation" : "參閱說明文件",
+    "{name} version {version} and above" : "{name} 版本 {version} 以上",
     "This browser is not supported" : "不支援此瀏覽器",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
     "Continue with this unsupported browser" : "繼續使用不受支援的瀏覽器",
     "Supported versions" : "支援的版本",
-    "{name} version {version} and above" : "{name} 版本 {version} 以上",
     "Search {types} …" : "搜尋 {types} 中…",
     "Choose {file}" : "選擇 {file}",
     "Choose" : "選擇",
@@ -247,11 +409,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "搜尋現有專案",
     "New in" : "新加入",
     "View changelog" : "檢視版本更新紀錄",
-    "Very weak password" : "密碼安全性極弱",
-    "Weak password" : "密碼安全性弱",
-    "So-so password" : "密碼安全性普通",
-    "Good password" : "密碼安全性佳",
-    "Strong password" : "密碼安全性極佳",
     "No action available" : "沒有可用的動作",
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
@@ -269,9 +426,10 @@ OC.L10N.register(
     "Admin" : "管理",
     "Help" : "說明",
     "Access forbidden" : "存取被拒",
+    "You are not allowed to access this page." : "您無法存取此頁面。",
+    "Back to %s" : "返回 %s",
     "Page not found" : "找不到頁面",
     "The page could not be found on the server or you may not be allowed to view it." : "在伺服器上找不到該頁面，或者您可能無權檢視。",
-    "Back to %s" : "返回 %s",
     "Too many requests" : "太多請求",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自您的網路，請稍後再試。若您認為這不該發生，請聯絡系統管理員這是錯誤。",
     "Error" : "錯誤",
@@ -289,32 +447,6 @@ OC.L10N.register(
     "File: %s" : "檔案：%s",
     "Line: %s" : "行號：%s",
     "Trace" : "追蹤",
-    "Security warning" : "安全性警告",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 .htaccess 檔案並未生效。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明文件</a>來瞭解如何正確設定您的伺服器組態。",
-    "Create an <strong>admin account</strong>" : "建立<strong>管理員帳號</strong>",
-    "Show password" : "顯示密碼",
-    "Toggle password visibility" : "切換密碼可見性",
-    "Storage & database" : "儲存空間和資料庫",
-    "Data folder" : "資料儲存位置",
-    "Configure the database" : "設定資料庫組態",
-    "Only %s is available." : "剩下 %s 可使用。",
-    "Install and activate additional PHP modules to choose other database types." : "安裝並啟用相關 PHP 模組來選擇其他資料庫類型。",
-    "For more details check out the documentation." : "請參閱說明文件了解更多細節。",
-    "Database account" : "資料庫帳號",
-    "Database password" : "資料庫密碼",
-    "Database name" : "資料庫名稱",
-    "Database tablespace" : "資料庫資料表空間",
-    "Database host" : "資料庫主機",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
-    "Performance warning" : "效能警告",
-    "You chose SQLite as database." : "您選擇了 SQLite 作為資料庫。",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或開發中站台。對於正式上線用途，我們建議改用其他資料庫後端。",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若您會使用桌面版或手機版客戶端同步檔案，則強烈不建議使用 SQLite。",
-    "Install" : "安裝",
-    "Installing …" : "正在安裝…",
-    "Need help?" : "需要協助嗎？",
-    "See the documentation" : "參閱說明文件",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "您似乎正在嘗試重新安裝 Nextcloud。然而，檔案 CAN_INSTALL 並不在您的 config 目錄中。請在您的 config 資料夾中建立 CAN_INSTALL 檔以繼續。",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "無法從 config 資料夾中移除 CAN_INSTALL 檔案。請手動移除此檔案。",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "此應用程式需要 JavaScript 才能正常運作。請 {linkstart} 啟用 JavaScript{linkend} 然後重新載入頁面。",
@@ -373,45 +505,31 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 站台目前處於維護模式，需要一段時間恢復。",
     "This page will refresh itself when the instance is available again." : "在站台恢復可用之後，本頁會自動重新整理。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
-    "The user limit of this instance is reached." : "已達此站台的使用者數量上限。",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "請在支援應用程式中輸入您的訂閱方案金鑰，以提高使用者數量限制。這也能賦予您 Nextcloud 企業版提供的所有其他好處，特別是可用於公司營運上的項目，十分推薦。",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 介面似乎為故障狀態，導致您的網頁伺服器無法提供檔案同步功能。",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的網頁伺服器未正確設定，無法解析「{url}」。想了解更多資訊，請見 {linkstart} 文件 ↗{linkend}。",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "您的網頁伺服器未正確設定，無法解析「{url}」。這可能與伺服器的組態設定，未更新為直接傳送此資料夾有關。請對應查看您的組態設定，例如 Apache 中的「.htaccess」檔案，請比較一下附上的重寫規則；或請查看 Nginx {linkstart} 文件頁面 ↗{linkend} 中所提供的文件。在 Nginx 環境中，通常是在「location ~」開頭的那行需要調整更新。",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "您的網頁伺服器未正確設定，無法傳遞 .woff2 檔案。這通常是因為 Nginx 的組態設定問題導致。在 Nextcloud 15 中，需要一些調整才能一起傳遞 .woff2 檔案。請確認您的 Nginx 組態設定，並比較一下我們 {linkstart} 說明文件 ↗{linkend} 中的建議設定。",
-    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "您經由安全的連線存取系統，但站台卻生成了不安全的 URL。這很有可能是因為您使用了反向代理伺服器，而反向代理伺服器的改寫規則並未正常運作。請參閱 {linkstart} 關於此問題的文件頁面 ↗{linkend}。",
-    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案，似乎可以從網際網路上公開存取。這表示 .htaccess 組態檔並未生效，我們強烈建議您調整網頁伺服器的組態設定，來阻絕資料目錄存取，或者將您的資料目錄移出網頁伺服器根目錄。",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的「{header}」標頭設定並不是「{expected}」。這有潛在的安全性與隱私風險，我們建議調整此項設定。",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的「{header}」標頭設定並不是「{expected}」。這會讓某些功能無法正常運作，我們建議調整此項設定。",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的「{header}」標頭設定並不包含「{expected}」 。這有潛在的安全性與隱私風險，我們建議調整此項設定。",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "目前 HTTP 的「{header}」標頭設定並不是「{val1}」、「{val2}」、「{val3}」、「{val4}」或「{val5}」。這會洩漏一些資訊。{linkstart} 請參閱 W3C 建議文件 ↗{linkend}。",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP「Strict-Transport-Security」標頭並未被設定持續至少 {seconds} 秒。為了強化安全性，我們在 {linkstart} 安全建議 ↗{linkend} 中有詳述並建議啟用 HSTS。",
-    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "您正在透過不安全的 HTTP 存取網站，強烈建議您設定您的伺服器啟用 HTTPS。更多資訊請參閱 {linkstart} 安全建議 ↗{linkend}。若不將伺服器設定為以 HTTPS 運作，部份重要的網站功能，如「複製到剪貼簿」或「Service Worker」將無法運作！",
-    "Currently open" : "目前開啟",
-    "Wrong username or password." : "錯誤的使用者名稱或密碼。",
-    "User disabled" : "使用者已停用",
-    "Login with username or email" : "以使用者名稱或電子郵件登入",
-    "Login with username" : "以使用者名稱登入",
-    "Username or email" : "使用者名稱或電子郵件",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "若此帳號存在，密碼重設郵件即已寄送至其電子郵件地址。若您未收到，請核對您的電子郵件地址及/或帳號名稱，並檢查您的垃圾郵件資料夾，或向您的本機管理員求助。",
+    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "詳細資訊請參閱 {linkstart} 文件 ↗{linkend}。",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議、網路研討會等 - 在您的瀏覽器與手機應用程式之中實現。",
-    "Edit Profile" : "編輯個人檔案",
-    "The headline and about sections will show up here" : "標題與關於區段將在此顯示",
     "You have not added any info yet" : "您尚未新增任何資訊",
     "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
     "Error opening the user status modal, try hard refreshing the page" : "開啟使用者狀態的模組時發生問題，嘗試重新整理頁面",
-    "Apps and Settings" : "應用程式與設定",
-    "Error loading message template: {error}" : "載入訊息範本時發生錯誤：{error}",
-    "Users" : "使用者",
+    "Edit Profile" : "編輯個人檔案",
+    "The headline and about sections will show up here" : "標題與關於區段將在此顯示",
+    "Very weak password" : "密碼安全性極弱",
+    "Weak password" : "密碼安全性弱",
+    "So-so password" : "密碼安全性普通",
+    "Good password" : "密碼安全性佳",
+    "Strong password" : "密碼安全性極佳",
     "Profile not found" : "找不到個人檔案",
     "The profile does not exist." : "個人檔案不存在。",
-    "Username" : "使用者名稱",
-    "Database user" : "資料庫使用者",
-    "This action requires you to confirm your password" : "此動作需要您再次確認密碼",
-    "Confirm your password" : "確認密碼",
-    "Confirm" : "確認",
-    "App token" : "應用程式代符",
-    "Alternative log in using app token" : "使用應用程式代符作其他登入用",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "因為您的站台有超過 50 位使用者，服務規模較大，請透過命令列介面更新。"
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 .htaccess 檔案並未生效。",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明文件</a>來瞭解如何正確設定您的伺服器組態。",
+    "<strong>Create an admin account</strong>" : "<strong>建立管理員帳號</strong>",
+    "New admin account name" : "新管理員帳號名稱",
+    "New admin password" : "新管理員密碼",
+    "Show password" : "顯示密碼",
+    "Toggle password visibility" : "切換密碼可見性",
+    "Configure the database" : "設定資料庫組態",
+    "Only %s is available." : "剩下 %s 可使用。",
+    "Database account" : "資料庫帳號",
+    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿"
 },
 "nplurals=1; plural=0;");
