@@ -1,7 +1,7 @@
 OC.L10N.register(
     "lib",
     {
-    "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire « config » !",
+    "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire \"config\" !",
     "This can usually be fixed by giving the web server write access to the config directory." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire de configuration.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option « config_is_read_only » sur true.",
     "See %s" : "Voir %s",
@@ -19,11 +19,11 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s et %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s et %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s et %5$s",
-    "Education Edition" : "Édition pour l'éducation ",
+    "Education bundle" : "Pack pour éducation",
     "Enterprise bundle" : "Pack pour entreprise",
     "Groupware bundle" : "Pack Groupware",
     "Hub bundle" : "Pack Nextcloud Hub",
-    "Public sector bundle" : "Bundle du secteur public",
+    "Public sector bundle" : "Pack pour secteur public",
     "Social sharing bundle" : "Pack pour partage social",
     "PHP %s or higher is required." : "PHP %s ou supérieur est requis.",
     "PHP with a version lower than %s is required." : "PHP avec une version antérieure à %s est requis.",
@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Un serveur de version %s ou supérieure est requis.",
     "Server version %s or lower is required." : "Un serveur de version %s ou inférieure est requis.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Le compte connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
+    "Your current IP address doesn't allow you to perform admin actions" : "Votre adresse IP actuelle ne vous permet pas d'effectuer des actions d'administration",
     "Logged in account must be an admin or sub admin" : "Le compte connecté doit être administrateur ou sous-administrateur",
     "Logged in account must be an admin" : "Le compte connecté doit être un administrateur",
     "Wiping of device %s has started" : "L'effaçage de l'appareil %s a démarré",
@@ -58,6 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "L'image d'avatar n'est pas carrée",
     "Files" : "Fichiers",
     "View profile" : "Voir le profil",
+    "same time" : "même moment",
+    "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
+    "_%nm_::_%nm_" : ["%nm","%nm","%nm"],
+    "%s ahead" : "%s en plus",
+    "%s behind" : "%s en moins",
     "Local time: %s" : "Heure locale : %s",
     "today" : "aujourd’hui",
     "tomorrow" : "demain",
@@ -80,14 +86,36 @@ OC.L10N.register(
     "seconds ago" : "il y a quelques secondes",
     "Empty file" : "Fichier vide",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Le module avec l'ID: %s n'existe pas. Merci de l'activer dans les paramètres d'applications ou de contacter votre administrateur.",
+    "No file conversion providers available" : "Pas de fournisseur de conversion de fichier disponible",
+    "File is too large to convert" : "Le fichier est trop gros pour être converti",
+    "Destination does not match conversion extension" : "L'extension du fichier de destination ne correspond pas à la conversion",
+    "Could not convert file" : "Impossible de convertir le fichier",
+    "Destination does not exist" : "La destination n'existe pas",
+    "Destination is not creatable" : "La destination ne peut pas être créée",
+    "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
+    "%1$s (renamed)" : "%1$s (renommé)",
+    "renamed file" : "fichier renommé",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" est un nom de fichier ou de dossier interdit.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" est un préfixe interdit pour les noms de fichiers ou de dossiers.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" n'est pas autorisé dans un nom de fichier ou de dossier.",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" est un type de fichier interdit.",
+    "Filenames must not end with \"%1$s\"." : "Les noms de fichiers ne doivent pas se terminer par \"%1$s\".",
+    "Invalid parent path" : "Chemin parent invalide",
     "File already exists" : "Le fichier existe déjà",
     "Invalid path" : "Chemin incorrect",
     "Failed to create file from template" : "Impossible de créer le fichier à partir du modèle",
     "Templates" : "Modèles",
-    "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
-    "File name contains at least one invalid character" : "Le nom de fichier contient au moins un caractère invalide",
-    "File name is too long" : "Nom de fichier trop long",
-    "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
+    "Storage %s cannot be moved" : "L'emplacement de stockage %s ne peut être déplacé",
+    "Moving a share (%s) into a shared folder is not allowed" : "Déplacer un partage (%s) dans un dossier partagé n'est pas autorisé",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Déplacer un emplacement de stockage (%s) dans un dossier partagé n'est pas autorisé",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Déplacer un partage (%s) dans un autre partage (%s) n'est pas autorisé",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Déplacer un partage (%s) dans un autre emplacement (%s) n'est pas autorisé",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Déplacer un emplacement de stockage (%s) dans un partage (%s) n'est pas autorisé",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Déplacer un emplacement de stockage (%s) dans un autre emplacement de stockage (%s) n'est pas autorisé",
+    "Path contains invalid segments" : "Le chemin contient des segments invalides",
+    "Filename is a reserved word" : "Le nom de fichier est un mot réservé",
+    "Filename contains at least one invalid character" : "Le nom du fichier contient au moins un caractère invalide",
+    "Filename is too long" : "Le nom de fichier est trop long",
     "Empty filename is not allowed" : "Le nom de fichier n'est pas autorisé",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'application « %s » ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'application « %s » ne peut être installée car elle n'est pas compatible avec cette version du serveur.",
@@ -100,24 +128,27 @@ OC.L10N.register(
     "Administration settings" : "Paramètres d'administration",
     "Settings" : "Paramètres",
     "Log out" : "Se déconnecter",
-    "Users" : "Utilisateurs",
+    "Accounts" : "Comptes",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Voir %s sur Bluesky",
     "Email" : "E-mail",
-    "Mail %s" : "Courrier %s",
+    "Mail %s" : "E-mail %s",
     "Fediverse" : "Fediverse",
     "View %s on the fediverse" : "Voir %s sur le Fediverse",
     "Phone" : "Téléphone",
     "Call %s" : "Appel %s",
     "Twitter" : "Twitter",
     "View %s on Twitter" : "Voir %s sur Twitter",
-    "Website" : "Site web",
+    "Website" : "Site internet",
     "Visit %s" : "Visiter %s",
     "Address" : "Adresse",
     "Profile picture" : "Photo de profil",
     "About" : "À propos",
     "Display name" : "Nom d'affichage",
     "Headline" : "Titre",
-    "Organisation" : "Organisme",
+    "Organization" : "Organisation",
     "Role" : "Fonction",
+    "Pronouns" : "Pronoms",
     "Unknown account" : "Compte inconnu",
     "Additional settings" : "Paramètres supplémentaires",
     "Enter the database Login and name for %s" : "Saisissez l'identifiant et le nom de la base de données pour %s",
@@ -129,7 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "La connexion Oracle ne peut être établie",
     "Oracle Login and/or password not valid" : "Identifiant et/ou mot de passe Oracle invalide",
     "PostgreSQL Login and/or password not valid" : "Identifiant et/ou mot de passe PostgreSQL invalide",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plate-forme. Son utilisation est à vos risques et périls !",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plateforme. Vous l'utilisez à vos risques et périls ! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Pour obtenir les meilleurs résultats, vous devriez utiliser un serveur GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32 bits et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez retirer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
@@ -139,26 +170,61 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Le service de partage %s doit implémenter l'interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Service de partage %s non trouvé",
     "Sharing backend for %s not found" : "Le service de partage pour %s est introuvable",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s a partagé « %2$s » avec vous et souhaite ajouter :",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s a partagé « %2$s » avec vous et souhaite ajouter",
-    "»%s« added a note to a file shared with you" : "%s a ajouté une note à un fichier partagé avec vous",
-    "Open »%s«" : "Ouvrir « %s »",
+    "%1$s shared %2$s with you" : "%1$s a partagé %2$s avec vous",
+    "Open %s" : "Ouvrir %s",
     "%1$s via %2$s" : "%1$s via %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s a partagé %2$s avec vous et souhaite ajouter :",
+    "%1$s shared %2$s with you and wants to add" : "%1$s a partagé %2$s avec vous et souhaite ajouter",
+    "%s added a note to a file shared with you" : "%s a ajouté une note à un fichier partagé avec vous",
+    "Passwords are enforced for link and mail shares" : "Les mots de passe sont appliqués pour les partages de liens et de courriers électroniques",
+    "Share recipient is not a valid user" : "Le destinataire du partage n'est pas un utilisateur valide",
+    "Share recipient is not a valid group" : "Le destinataire du partage n'est pas un groupe valide",
+    "Share recipient should be empty" : "Le destinataire du partage doit être vide",
+    "Share recipient should not be empty" : "Le destinataire du partage ne doit pas être vide",
+    "Share recipient is not a valid circle" : "Le destinataire du partage n'est pas un cercle valide",
+    "Unknown share type" : "Type de partage inconnu",
+    "Share initiator must be set" : "L'initiateur du partage doit être défini",
+    "Cannot share with yourself" : "Vous ne pouvez pas partager avec vous-même",
+    "Shared path must be set" : "Le chemin partagé doit être défini",
+    "Shared path must be either a file or a folder" : "Le chemin partagé doit être soit un fichier, soit un dossier",
+    "You cannot share your root folder" : "Vous ne pouvez pas partager votre dossier racine",
     "You are not allowed to share %s" : "Vous n’êtes pas autorisé à partager %s",
+    "Valid permissions are required for sharing" : "Des autorisations valides sont requises pour le partage",
+    "File shares cannot have create or delete permissions" : "Les partages de fichier ne peuvent avoir de permission de création ou de suppression",
     "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
+    "Shares need at least read permissions" : "Les partages nécessitent au moins des autorisations de lecture",
     "Files cannot be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
     "Files cannot be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
     "Expiration date is in the past" : "La date d’expiration est dans le passé",
+    "Expiration date is enforced" : "La date d'expiration est appliquée",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossible de définir la date d'expiration à dans plus de %n jour","Impossible de définir la date d'expiration à dans plus de %n jours","Impossible de définir la date d'expiration à dans plus de %n jours"],
     "Sharing is only allowed with group members" : "Le partage n'est que possible qu'avec les membres du groupe",
     "Sharing %s failed, because this item is already shared with the account %s" : "Impossible de partager %s car il est déjà partagé avec le compte %s",
-    "%1$s shared »%2$s« with you" : "%1$s a partagé « %2$s » avec vous",
-    "%1$s shared »%2$s« with you." : "%1$s a partagé « %2$s » avec vous.",
-    "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir",
+    "Group sharing is now allowed" : "Le partage de groupe est désormais autorisé",
+    "Sharing is only allowed within your own groups" : "Le partage n'est autorisé qu'au sein de vos propres groupes",
+    "Path is already shared with this group" : "Le chemin est déjà partagé avec ce groupe",
+    "Link sharing is not allowed" : "Le partage de liens n'est pas autorisé",
+    "Public upload is not allowed" : "Le téléversement public n'est pas autorisé",
+    "You cannot share a folder that contains other shares" : "Vous ne pouvez pas partager un dossier qui contient déjà d'autres partages.",
+    "Sharing is disabled" : "Le partage est désactivé",
+    "Sharing is disabled for you" : "Le partage est désactivé pour vous",
+    "Cannot share with the share owner" : "Impossible de partager avec le propriétaire de l'action",
+    "Share does not have a full ID" : "Le partage n'a pas d'identifiant complet",
+    "Cannot change share type" : "Impossible de changer le type de partage",
+    "Can only update recipient on user shares" : "Impossible de mettre à jour le destinataire uniquement sur les partages utilisateur",
+    "Cannot enable sending the password by Talk with an empty password" : "Impossible d'activer l'envoi du mot de passe par Talk avec un mot de passe vide",
+    "Cannot enable sending the password by Talk without setting a new password" : "Impossible d'activer l'envoi du mot de passe par Talk sans définir un nouveau mot de passe",
+    "Cannot disable sending the password by Talk without setting a new password" : "Impossible de désactiver l'envoi du mot de passe par Talk sans définir un nouveau mot de passe",
+    "Share provider does not support accepting" : "Le fournisseur de partage ne prend pas en charge l'acceptation",
+    "Cannot change target of link share" : "Impossible de modifier la cible du partage de lien",
+    "Invalid share recipient" : "Destinataire du partage non valide",
+    "Group \"%s\" does not exist" : "Le groupe \"%s\" n'existe pas",
     "The requested share does not exist anymore" : "Le partage demandé n'existe plus",
     "The requested share comes from a disabled user" : "Le partage demandé provient d'un utilisateur désactivé",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "L'utilisateur n'a pas été créé car la limite du nombre d'utilisateurs a été atteinte. Consultez vos notifications pour en savoir plus.",
     "Could not find category \"%s\"" : "Impossible de trouver la catégorie « %s »",
+    "Input text" : "Texte d'entrée",
+    "The input text" : "Le texte d'entrée",
     "Sunday" : "Dimanche",
     "Monday" : "Lundi",
     "Tuesday" : "Mardi",
@@ -211,13 +277,12 @@ OC.L10N.register(
     "A valid Login must be provided" : "Un identifiant valide doit être saisi",
     "Login contains whitespace at the beginning or at the end" : "L'identifiant contient des espaces au début ou à la fin",
     "Login must not consist of dots only" : "L'identifiant ne doit pas être composé uniquement de points",
+    "Username is too long" : "Le nom d'utilisateur est trop long",
     "Login is invalid because files already exist for this user" : "L’identifiant n'est pas valide car des fichiers existent déjà pour cet utilisateur",
     "Account disabled" : "Compte désactivé",
     "Login canceled by app" : "L'authentification a été annulée par l'application",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'application « %1$s » ne peut pas être installée à cause des dépendances suivantes non satisfaites : %2$s",
     "a safe home for all your data" : "un lieu sûr pour toutes vos données",
-    "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
-    "Cannot download file" : "Impossible de télécharger le fichier",
     "Application is not enabled" : "L'application n'est pas activée",
     "Authentication error" : "Erreur d'authentification",
     "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
@@ -225,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Impossible d’écrire dans le répertoire « config ».",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire « config ». Voir %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option « config_is_read_only » sur true. Voir %s",
-    "Cannot write into \"apps\" directory." : "Impossible d'écrire dans le répertoire « apps ».",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
     "Cannot create \"data\" directory." : "Impossible de créer le dossier \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Le problème de permissions peut généralement être résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s.",
@@ -237,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Le paramètre PHP « %s » n'est pas « %s ».",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajuster ce paramètre dans php.ini fera fonctionner Nextcould à nouveau",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> est défini à <code>%s</code> alors que la valeur <code>0</code> est attendue.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pour corriger ce problème définissez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP semble configuré de manière à supprimer les blocs PHPdoc du code. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Les modules PHP ont été installés mais sont toujours indiqués comme manquants ?",
@@ -250,7 +311,7 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Le chemin de votre répertoire doit être un chemin absolu.",
     "Check the value of \"datadirectory\" in your configuration." : "Verifiez la valeur de \"datadirectory\" dans votre configuration.",
     "Your data directory is invalid." : "Votre répertoire des données n'est pas valide.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assurez-vous que le répertoire de données contient un fichier \".ocdata\" à sa racine.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Assurez-vous qu'il existe un fichier appelé \"%1$s\" à la racine du répertoire de données. Il doit avoir le contenu suivant : \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "Action \"%s\" non supportée ou implémentée.",
     "Authentication failed, wrong token or provider ID given" : "Échec de l'authentification, jeton erroné ou identification du fournisseur donnée",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Paramètres manquants pour compléter la requête. Paramètres manquants : \"%s\"",
@@ -262,38 +323,158 @@ OC.L10N.register(
     "Storage connection error. %s" : "Erreur de connexion à l’espace stockage. %s",
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Pour autoriser cette vérification, pour devez vous assurer que votre serveur web peut se connecter à lui-même. Il doit donc être capable de résoudre et de se connecter à au moins un de ses `trusted_domains` ou à l'URL `overwrite.cli.url`. Cet échec peut être le résultat d'une erreur de DNS côté serveur ou d'une règle de pare-feu sortante.",
+    "Analyze images" : "Analyser des images",
+    "Ask a question about the given images." : "Poser une question sur les images fournies.",
+    "Images" : "Images",
+    "Images to ask a question about" : "Images pour lesquelles poser la question",
+    "Question" : "Question",
+    "What to ask about the images." : "Que demander au sujet des images.",
+    "Generated response" : "Réponse générée",
+    "The answer to the question" : "La réponse à la question",
+    "Audio chat" : "Discussion audio",
+    "Voice chat with the assistant" : "Discussion vocale avec l'assistant",
+    "System prompt" : "Invite du système",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Définir les règles et les hypothèses que l'assistant doit suivre pendant la conversation.",
+    "Chat voice message" : "Message vocal",
+    "Describe a task that you want the assistant to do or ask a question." : "Décrivez une tâche que vous souhaitez confier à l'assistant ou posez une question.",
+    "Chat history" : "Historique de la discussion",
+    "The history of chat messages before the current message, starting with a message by the user." : "L'historique des messages précédant le message actuel, en commençant par un message de l'utilisateur.",
+    "Input transcript" : "Transcription de l'entrée",
+    "Transcription of the audio input" : "Transcription de l'entrée audio",
+    "Response voice message" : "Message vocal de réponse",
+    "The generated voice response as part of the conversation" : "La réponse vocale générée dans le cadre de la conversation",
+    "Output transcript" : "Transcription de la sortie",
+    "Transcription of the audio output" : "Transcription de la sortie audio",
+    "Transcribe audio" : "Transcrire de l'audio",
+    "Transcribe the things said in an audio" : "Transcrire les propos exprimés dans un fichier audio",
+    "Audio input" : "Entrée audio",
+    "The audio to transcribe" : "Audio à retranscrire",
+    "Transcription" : "Transcription",
+    "The transcribed text" : "Le texte transcrit",
+    "Chat by voice with an agent" : "Discuter vocalement avec un agent",
+    "Describe a task that you want the agent to do or ask a question." : "Décrivez une tâche que vous souhaitez confier à l'agent ou posez-lui une question.",
+    "Confirmation" : "Confirmation",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Confirmation des actions demandées précédemment : 0 pour refuser et 1 pour confirmer.",
+    "Conversation token" : "Jeton de conversation",
+    "A token representing the conversation." : "Un jeton représentant la conversation.",
+    "The new conversation token" : "Le nouveau jeton de conversation",
+    "Send this along with the next interaction." : "Envoyer ceci lors de la prochaine interaction.",
+    "Requested actions by the agent" : "Actions demandées par l'agent",
+    "Actions that the agent would like to carry out in JSON format." : "Actions que l'agent souhaiterait effectuer au format JSON.",
+    "Chat with an agent" : "Discuter avec un agent conversationnel",
+    "Chat message" : "Message de discussion",
+    "A chat message to send to the agent." : "Un message instantané à envoyer à l'agent.",
+    "The response from the chat model." : "La réponse du modèle de messagerie instantanée",
+    "Context write" : "Écrire selon un contexte",
+    "Writes text in a given style based on the provided source material." : "Écrit un texte dans un style donné, basé sur des données initiales préalablement fournies.",
+    "Writing style" : "Style rédactionnel",
+    "Demonstrate a writing style that you would like to immitate" : "Montrez un style d'écriture que vous aimeriez imiter",
+    "Source material" : "Données initiales",
+    "The content that would like to be rewritten in the new writing style" : "Contenu qui doit être réécrit dans le nouveau style de rédaction",
+    "Generated text" : "Texte généré",
+    "The generated text with content from the source material in the given style" : "Le texte généré reprend le contenu du document source dans le style donné",
+    "Emoji generator" : "Générateur d'émoji",
+    "Takes text and generates a representative emoji for it." : "Prend un texte et génère un émoji représentatif.",
+    "The text to generate an emoji for" : "Texte pour lequel générer un émoji",
+    "Generated emoji" : "Émoji généré",
+    "The generated emoji based on the input text" : "Émoji généré en fonction du texte saisi",
+    "Generate image" : "Générer une image",
+    "Generate an image from a text prompt" : "Générer une image à partir d'un texte",
+    "Prompt" : "Prompt",
+    "Describe the image you want to generate" : "Décrivez l'image que vous souhaitez générer",
+    "Number of images" : "Nombre d'images",
+    "How many images to generate" : "Nombre d'images à générer",
+    "Output images" : "Images de sortie",
+    "The generated images" : "Les images générées",
+    "Generate speech" : "Générer une synthèse vocale",
+    "Generate speech from a transcript" : "Générer synthèse vocale à partir d'une transcription",
+    "Write transcript that you want the assistant to generate speech from" : "Écrire la transcription à partir de laquelle vous voulez générer la synthèse vocale",
+    "Output speech" : "Synthèse vocale",
+    "The generated speech" : "La synthèse vocale générée",
+    "Free text to text prompt" : "Texte libre à texte libre",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Exécute une commande arbitraire à l'aide d'un modèle linguistique qui génère une réponse",
+    "Describe a task that you want the assistant to do or ask a question" : "Décrivez une tâche que vous voulez que l'assistant effectue ou posez une question",
+    "Generated reply" : "Réponse générée",
+    "The generated text from the assistant" : "Texte généré par l'assistant",
+    "Change Tone" : "Changer de ton",
+    "Change the tone of a piece of text." : "Changer le ton d'un morceau de texte.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Écrivez un texte que vous souhaitez voir réécrit dans un autre ton par l'assistant",
+    "Desired tone" : "Ton souhaité",
+    "In which tone should your text be rewritten?" : "Dans quel ton souhaitez-vous que votre texte soit réécrit ?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Le texte réécrit dans le ton souhaité par l'assistant : ",
+    "Chat" : "Discussion instantanée ",
+    "Chat with the assistant" : "Discuter avec l'assistant",
+    "The history of chat messages before the current message, starting with a message by the user" : "Historique des messages de discussion avant le message actuel, commençant par un message de l'utilisateur",
+    "Response message" : "Message de réponse",
+    "The generated response as part of the conversation" : "Réponse générée comme partie de la conversation",
+    "Chat with tools" : "Discuter en utilisant les fonctions",
+    "Chat with the language model with tool calling support." : "Discuter avec le modèle de langage en utilisant les fonctions",
+    "Tool message" : "Message d'outil",
+    "The result of tool calls in the last interaction" : "Le résultat des appels de fonction lors de la dernière interaction",
+    "Available tools" : "Fonctions de rappel disponibles",
+    "The available tools in JSON format" : "Les fonctions disponibles en format JSON",
+    "The response from the chat model" : "La réponse du modèle de discussion instantanée",
+    "Tool calls" : "Appels de fonction",
+    "Tools call instructions from the model in JSON format" : "Instructions d'appel d'outil depuis le modèle au format JSON",
+    "Formalize text" : "Formaliser un texte",
+    "Takes a text and makes it sound more formal" : "Prend un texte et le rend plus formel",
+    "Write a text that you want the assistant to formalize" : "Rédigez un texte que vous souhaitez que l'assistant formalise",
+    "Formalized text" : "Texte formalisé",
+    "The formalized text" : "Texte formalisé",
+    "Generate a headline" : "Générer un titre",
+    "Generates a possible headline for a text." : "Génère un titre possible pour un texte.",
+    "Original text" : "Texte original",
+    "The original text to generate a headline for" : "Texte original pour lequel générer un titre",
+    "The generated headline" : "Titre généré",
+    "Proofread" : "Relire",
+    "Proofreads a text and lists corrections" : "Relit un texte et liste les corrections",
+    "Text" : "Texte",
+    "The text to proofread" : "Le texte à relire",
+    "Corrections" : "Corrections",
+    "The corrections that should be made in your text" : "Les corrections que vous devriez apporter à votre texte",
+    "Reformulate text" : "Reformuler un texte",
+    "Takes a text and reformulates it" : "Prend un texte et le reformule",
+    "Write a text that you want the assistant to reformulate" : "Rédigez un texte que vous souhaitez que l'assistant reformule",
+    "Reformulated text" : "Texte reformulé",
+    "The reformulated text, written by the assistant" : "Texte reformulé, rédigé par l'assistant",
+    "Simplify text" : "Simplifier le texte",
+    "Takes a text and simplifies it" : "Prend un texte et le simplifie",
+    "Write a text that you want the assistant to simplify" : "Rédigez un texte que vous souhaitez que l'assistant simplifie",
+    "Simplified text" : "Texte simplifié",
+    "The simplified text" : "Le texte simplifié",
+    "Summarize" : "Résumer",
+    "Summarizes a text" : "Résumer un texte",
+    "The original text to summarize" : "Le texte original à résumer",
+    "Summary" : "Résumé",
+    "The generated summary" : "Le résumé généré",
+    "Extract topics" : "Extraire des sujets",
+    "Extracts topics from a text and outputs them separated by commas" : "Extrait les sujets d'un texte et les affiche en les séparant par des virgules.",
+    "The original text to extract topics from" : "Texte original à partir duquel les thèmes sont extraits",
+    "Topics" : "Sujets",
+    "The list of extracted topics" : "La liste des sujets extraits",
+    "Translate" : "Traduire",
+    "Translate text from one language to another" : "Traduire un texte d'une langue à une autre",
+    "Origin text" : "Texte d'origine",
+    "The text to translate" : "Texte à traduire",
+    "Origin language" : "Langue d'origine",
+    "The language of the origin text" : "Langue du texte d'origine",
+    "Target language" : "Langue cible",
+    "The desired language to translate the origin text in" : "Langue souhaitée pour la traduction du texte d'origine",
+    "Result" : "Résultat",
+    "The translated text" : "Le texte traduit",
     "Free prompt" : "Prompt",
     "Runs an arbitrary prompt through the language model." : "Exécute une commande arbitraire via le modèle de langage.",
     "Generate headline" : "Générer un titre",
-    "Generates a possible headline for a text." : "Génère un titre possible pour un texte.",
-    "Summarize" : "Résumer",
     "Summarizes text by reducing its length without losing key information." : "Résume un texte en réduisant sa longueur sans perdre d’informations essentielles.",
-    "Extract topics" : "Extraire des thèmes",
     "Extracts topics from a text and outputs them separated by commas." : "Extrait les thèmes d'un texte et les restitue séparés par des virgules.",
-    "404" : "404",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utilisateur connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
-    "Logged in user must be an admin or sub admin" : "L'utilisateur connecté doit être administrateur ou sous-administrateur",
-    "Logged in user must be an admin" : "L'utilisateur connecté doit être un administrateur",
-    "Help" : "Aide",
-    "Unknown user" : "Utilisateur inconnu",
-    "Enter the database username and name for %s" : "Entrez le nom d'utilisateur et le nom de la base de données pour %s",
-    "Enter the database username for %s" : "Entrez le nom d'utilisateur de la base de données pour %s",
-    "MySQL username and/or password not valid" : "Nom d’utilisateur et/ou mot de passe de la base MySQL non valide(s)",
-    "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
-    "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
-    "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Impossible de partager %s car il est déjà partagé avec l'utilisateur %s",
-    "The username is already being used" : "Ce nom d’utilisateur est déjà utilisé",
-    "Could not create user" : "Impossible de créer l'utilisateur",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", espaces et \"_.@-'\"",
-    "A valid username must be provided" : "Un nom d’utilisateur valide doit être saisi",
-    "Username contains whitespace at the beginning or at the end" : "Le nom d’utilisateur contient des espaces au début ou à la fin",
-    "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
-    "Username is invalid because files already exist for this user" : "Ce nom d’utilisateur n’est pas valide car des fichiers existent déjà pour cet utilisateur",
-    "User disabled" : "Utilisateur désactivé",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 requis.",
-    "Please upgrade your database version." : "Veuillez mettre à jour votre gestionnaire de base de données.",
-    "Your data directory is readable by other users." : "Votre répertoire est lisible par d'autres utilisateurs.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs."
+    "Organisation" : "Organisme",
+    "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
+    "Cannot download file" : "Impossible de télécharger le fichier",
+    "Cannot write into \"apps\" directory." : "Impossible d'écrire dans le répertoire « apps ».",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> est défini à <code>%s</code> alors que la valeur <code>0</code> est attendue.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pour corriger ce problème définissez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini.",
+    "Login is too long" : "La connexion est trop longue"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
