@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Требуется сервер версии %s или выше.",
     "Server version %s or lower is required." : "Требуется сервер версии %s или ниже.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Для доступа к этой настройке зарегистрированная учетная запись должна быть администратором, субадминистратором или иметь специальные права",
+    "Your current IP address doesn't allow you to perform admin actions" : "Ваш текущий IP-адрес не позволяет вам выполнять действия администратора.",
     "Logged in account must be an admin or sub admin" : "Зарегистрированная учетная запись должна быть администратором или субадминистратором",
     "Logged in account must be an admin" : "Вошедший в систему пользователь должен быть администратором",
     "Wiping of device %s has started" : "Удаление данных с устройства «%s».",
@@ -58,7 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "Изображение аватара не квадратное",
     "Files" : "Файлы",
     "View profile" : "Открыть профиль",
+    "same time" : "в то же время",
     "_%nh_::_%nh_" : ["%nч","%nч","%nч","%nч"],
+    "_%nm_::_%nm_" : ["%nм","%nм","%n м","%n м"],
+    "%s ahead" : "%s вперёд",
+    "%s behind" : "%s позади",
     "Local time: %s" : "Местное время: %s",
     "today" : "сегодня",
     "tomorrow" : "завтра",
@@ -86,7 +91,10 @@ OC.L10N.register(
     "Destination does not match conversion extension" : "Назначение не соответствует расширению преобразования",
     "Could not convert file" : "Не удалось преобразовать файл",
     "Destination does not exist" : "Пункт назначения не существует",
+    "Destination is not creatable" : "Место назначения не может быть создано",
     "Dot files are not allowed" : "Файлы начинающиеся с точки не допускаются",
+    "%1$s (renamed)" : "%1$s (переименовано)",
+    "renamed file" : "переименованный файл",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" это запрещенное имя файла или папки.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" является запрещенным префиксом для имен файлов или папок.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" не допускается указывать имя файла или папки внутри него.",
@@ -97,6 +105,13 @@ OC.L10N.register(
     "Invalid path" : "Некорректный путь",
     "Failed to create file from template" : "Не удалось создать файл на основе шаблона",
     "Templates" : "Шаблоны",
+    "Storage %s cannot be moved" : "Хранилище %s не может быть перемещено",
+    "Moving a share (%s) into a shared folder is not allowed" : "Перемещение общего ресурса (%s) в общую папку запрещено",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Перемещение хранилища (%s) в общую папку запрещено",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Перемещение общего ресурса (%s) в другой общий ресурс (%s) запрещено",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Перемещение общего ресурса (%s) в другое хранилище (%s) запрещено",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Перемещение хранилища (%s) в общий ресурс (%s) запрещено",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Перемещение хранилища (%s) в другое хранилище (%s) запрещено",
     "Path contains invalid segments" : "Путь содержит недопустимые сегменты",
     "Filename is a reserved word" : "Имя файла - это зарезервированное слово",
     "Filename contains at least one invalid character" : "Имя файла содержит как минимум один недопустимый символ",
@@ -114,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Настройки",
     "Log out" : "Выйти",
     "Accounts" : "Учётные записи",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Просмотреть %s на Bluesky",
     "Email" : "Адрес эл. почты",
     "Mail %s" : "Написать %s",
     "Fediverse" : "Федиверс",
@@ -129,7 +146,7 @@ OC.L10N.register(
     "About" : "О себе",
     "Display name" : "Отображаемое имя",
     "Headline" : "Заголовок",
-    "Organisation" : "Организация",
+    "Organization" : "Организация",
     "Role" : "Роль",
     "Pronouns" : "Местоимения",
     "Unknown account" : "Неизвестный аккаунт",
@@ -143,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Соединение с Oracle не может быть установлено",
     "Oracle Login and/or password not valid" : "Неверный логин и/или пароль Oracle",
     "PostgreSQL Login and/or password not valid" : "Неверный логин и/или пароль для PostgreSQL",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X не поддерживается, и %s может работать некорректно на этой платформе. Используйте на свой страх и риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "Для достижения наилучших результатов, рассмотрите вариант использования сервера на GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной среде PHP и в php.ini был настроен open_basedir. Это приведёт к проблемам с файлами более 4 ГБ и настоятельно не рекомендуется.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Удалите директиву open_basedir из файла php.ini или смените PHP на 64-разрядную сборку.",
@@ -152,13 +170,27 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бэкенд общего доступа %s должен реализовывать интерфейс OCP\\Share_Backend",
     "Sharing backend %s not found" : "Механизм предоставления общего доступа %s не найден",
     "Sharing backend for %s not found" : "Не найден механизм предоставления общего доступа для %s ",
+    "%1$s shared %2$s with you" : "%1$s поделился(ась) %2$s с вами",
     "Open %s" : "Открыть %s",
     "%1$s via %2$s" : "%1$s через %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s поделился(ась) %2$s с вами и хочет добавить:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s поделился(ась) %2$s с вами и хочет добавить",
+    "%s added a note to a file shared with you" : "%s добавил(а) заметку к файлу, которым поделился(ась) с вами",
     "Passwords are enforced for link and mail shares" : "Для общих ссылок и почтовых рассылок применяются пароли",
+    "Share recipient is not a valid user" : "Получатель общего ресурса — некорректный пользователь",
+    "Share recipient is not a valid group" : "Получатель общего ресурса — некорректная группа",
+    "Share recipient should be empty" : "Получатель общего ресурса должен быть пустым",
+    "Share recipient should not be empty" : "Получатель общего ресурса не должен быть пустым",
+    "Share recipient is not a valid circle" : "Получатель общего ресурса — некорректный круг",
     "Unknown share type" : "Общий доступ неизвестного типа",
+    "Share initiator must be set" : "Должен быть задан инициатор общего ресурса",
     "Cannot share with yourself" : "Не могу поделиться с самим собой",
+    "Shared path must be set" : "Должен быть указан путь к общему ресурсу",
+    "Shared path must be either a file or a folder" : "Путь должен указывать на файл или папку",
     "You cannot share your root folder" : "Вы не можете предоставить общий доступ к своей корневой папке",
     "You are not allowed to share %s" : "Вам не разрешено делиться %s",
+    "Valid permissions are required for sharing" : "Для общего ресурса необходимы корректные права",
+    "File shares cannot have create or delete permissions" : "Для файловых общих ресурсов нельзя задавать права доступа на создание или удаление",
     "Cannot increase permissions of %s" : "Не удалось повысить права доступа %s",
     "Shares need at least read permissions" : "Общим ресурсам требуются как минимум разрешения на чтение",
     "Files cannot be shared with delete permissions" : "Права на удаление файлов не позволяют открывать общий доступ к ним",
@@ -173,6 +205,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Путь уже является общим для этой группы",
     "Link sharing is not allowed" : "Обмен ссылками запрещен",
     "Public upload is not allowed" : "Публичная загрузка данных запрещена",
+    "You cannot share a folder that contains other shares" : "Нельзя делиться папкой, содержащей другие общие ресурсы",
     "Sharing is disabled" : "Общий доступ отключен",
     "Sharing is disabled for you" : "Общий доступ для вас отключен",
     "Cannot share with the share owner" : "Невозможно поделиться с владельцем общего доступа",
@@ -184,6 +217,7 @@ OC.L10N.register(
     "Cannot disable sending the password by Talk without setting a new password" : "Невозможно отключить отправку пароля по телефону без установки нового пароля",
     "Share provider does not support accepting" : "Поставщик общего доступа не поддерживает прием",
     "Cannot change target of link share" : "Невозможно изменить цель публикации ссылки",
+    "Invalid share recipient" : "Некорректный получатель общего ресурса",
     "Group \"%s\" does not exist" : "Группа \"%s\" не существует",
     "The requested share does not exist anymore" : "Запрошенный общий ресурс более не существует.",
     "The requested share comes from a disabled user" : "Запрос на общий доступ поступает от отключенного пользователя",
@@ -243,6 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Необходимо указать действительный логин для входа в систему",
     "Login contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробелы в начале или в конце",
     "Login must not consist of dots only" : "Логин не должен состоять только из точек",
+    "Username is too long" : "Имя пользователя слишком длинное",
     "Login is invalid because files already exist for this user" : "Логин недействителен, поскольку файлы для этого пользователя уже существуют",
     "Account disabled" : "Учетная запись отключена",
     "Login canceled by app" : "Вход отменен приложением",
@@ -255,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Невозможно выполнить запись в каталог «config».",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в каталог конфигурации. Обратитесь к %s.",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Если для файла «config.php» должен быть установлен режим «только чтение», задайте параметру \"config_is_read_only\" значение \"true\". Изучите %s.",
-    "Cannot write into \"apps\" directory." : "Не удалось выполнить запись в каталог «apps».",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Обычно это можно исправить, предоставлением веб-серверу права для записи в каталог приложений или отключением магазина приложений в файле конфигурации.",
     "Cannot create \"data\" directory." : "Невозможно создать каталог «data».",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Обычно это можно исправить, предоставив веб-серверу права на запись в корневой каталог. Обратитесь к %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Разрешения обычно можно исправить, предоставив веб-серверу право на запись в корневой каталог. Обратитесь к %s.",
@@ -267,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Попросите администратора сервера установить этот модуль.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Параметру PHP «%s» не присвоено значение «%s».",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Настройка этого параметра в файле php.ini восстановит работоспособность Nextcloud",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Параметр <code>mbstring.func_overload</code> установлен в <code>%s</code>, но ожидается значение <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Чтобы исправить эту проблему установите параметр <code>mbstring.func_overload</code> в значение <code>0</code> в php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Очевидно, PHP настроен на вычищение блоков встроенной документации. Это сделает несколько центральных приложений недоступными.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кэшем/ускорителем вроде Zend OPcache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Модули PHP были установлены, но они все еще перечислены как недостающие?",
@@ -293,15 +324,47 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Хранилище временно недоступно",
     "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Чтобы разрешить эту проверку, вам нужно убедиться, что ваш веб-сервер может подключаться к себе. Поэтому он должен иметь возможность разрешать и подключаться по крайней мере к одному из своих `trusted_domains` или `overwrite.cli.url`. Эта ошибка может быть результатом несоответствия DNS на стороне сервера или исходящего правила брандмауэра.",
+    "Analyze images" : "Проанализировать изображения",
+    "Ask a question about the given images." : "Задать вопрос по предоставленным изображениям.",
+    "Images" : "Изображения",
+    "Images to ask a question about" : "Изображения для вопроса",
+    "Question" : "Вопрос",
+    "What to ask about the images." : "Что спросить об изображениях.",
+    "Generated response" : "Сгенерированный ответ",
+    "The answer to the question" : "Ответ на вопрос",
+    "Audio chat" : "Аудиочат",
+    "Voice chat with the assistant" : "Голосовой чат с помощником",
+    "System prompt" : "Системная подсказка",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Определите правила и допущения, которым ассистент должен следовать во время разговора.",
+    "Chat voice message" : "Голосовое сообщение в чате",
+    "Describe a task that you want the assistant to do or ask a question." : "Опишите задачу, которую вы хотите поручить помощнику, или задайте вопрос.",
+    "Chat history" : "История чата",
+    "The history of chat messages before the current message, starting with a message by the user." : "История сообщений в чате перед текущим сообщением, начиная с сообщения пользователя.",
+    "Input transcript" : "Текстовая расшифровка ввода",
+    "Transcription of the audio input" : "Текстовая расшифровка голосового ввода",
+    "Response voice message" : "Голосовой ответ",
+    "The generated voice response as part of the conversation" : "Сгенерированный голосовой ответ как часть беседы",
+    "Output transcript" : "Текстовая расшифровка вывода",
+    "Transcription of the audio output" : "Текстовая расшифровка голосового вывода",
     "Transcribe audio" : "Транскрибировать аудио",
     "Transcribe the things said in an audio" : "Запишите то, что было сказано в аудиозаписи",
     "Audio input" : "Аудиовход",
     "The audio to transcribe" : "Аудио для расшифровки",
     "Transcription" : "Транскрипция",
     "The transcribed text" : "Расшифрованный текст",
-    "Chat message" : "Сообщение в чате",
+    "Chat by voice with an agent" : "Общение голосом с агентом",
+    "Describe a task that you want the agent to do or ask a question." : "Опишите задачу, которую вы хотите поручить агенту, или задайте вопрос.",
     "Confirmation" : "Подтверждение",
-    "Generated response" : "Сгенерированный ответ",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Подтвердить ранее запрошенные действия: 0 — отказ, 1 — подтверждение.",
+    "Conversation token" : "Токен беседы",
+    "A token representing the conversation." : "Токен, представляющий беседу.",
+    "The new conversation token" : "Новый токен беседы",
+    "Send this along with the next interaction." : "Отправьте его при следующем взаимодействии.",
+    "Requested actions by the agent" : "Запрошенные действия от агента",
+    "Actions that the agent would like to carry out in JSON format." : "Действия, которые агент хотел бы выполнить в формате JSON.",
+    "Chat with an agent" : "Чат с агентом",
+    "Chat message" : "Сообщение в чате",
+    "A chat message to send to the agent." : "Сообщение для отправки агенту",
     "The response from the chat model." : "Ответ от модели чата.",
     "Context write" : "Контекстная запись",
     "Writes text in a given style based on the provided source material." : "Пишет текст в заданном стиле на основе предоставленного исходного материала.",
@@ -313,27 +376,47 @@ OC.L10N.register(
     "The generated text with content from the source material in the given style" : "Сгенерированный текст с содержимым из исходного материала в заданном стиле",
     "Emoji generator" : "Генератор Emoji",
     "Takes text and generates a representative emoji for it." : "Берет текст и генерирует для него репрезентативный смайлик.",
+    "The text to generate an emoji for" : "Текст для создания эмодзи",
+    "Generated emoji" : "Созданный эмодзи",
+    "The generated emoji based on the input text" : "Эмодзи, созданный на основе введённого текста",
     "Generate image" : "Генерировать изображение",
     "Generate an image from a text prompt" : "Создайте изображение из текстовой подсказки",
+    "Prompt" : "Подсказка",
     "Describe the image you want to generate" : "Опишите изображение, которое вы хотите создать",
     "Number of images" : "Количество изображений",
     "How many images to generate" : "Сколько изображений генерировать",
     "Output images" : "Выходные изображения",
     "The generated images" : "Сгенерированные изображения",
+    "Generate speech" : "Сгенерировать речь",
+    "Generate speech from a transcript" : "Сгенерировать речь из транскрипта",
+    "Write transcript that you want the assistant to generate speech from" : "Введите транскрипт, по которому ассистент должен сгенерировать речь",
+    "Output speech" : "Выходное аудио",
+    "The generated speech" : "Сгенерированная речь",
     "Free text to text prompt" : "Произвольное преобразование текста в текстовую подсказку",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Запускает произвольный запрос с помощью языковой модели, которая возвращает ответ",
     "Describe a task that you want the assistant to do or ask a question" : "Опишите задачу, которую вы хотите поручить ассистенту, или задайте вопрос",
     "Generated reply" : "Сгенерированный ответ",
     "The generated text from the assistant" : "Сгенерированный текст от помощника",
+    "Change Tone" : "Сменить тон",
+    "Change the tone of a piece of text." : "Изменить тон текста",
+    "Write a text that you want the assistant to rewrite in another tone." : "Напишите текст, чтобы ассистент переписал его в другом тоне.",
+    "Desired tone" : "Желаемый тон",
+    "In which tone should your text be rewritten?" : "В каком тоне следует переписать ваш текст?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Переписанный текст в нужном тоне, написанный ассистентом:",
     "Chat" : "Разговор",
     "Chat with the assistant" : "Пообщайтесь с ассистентом",
-    "System prompt" : "Системная подсказка",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Определите правила и допущения, которым ассистент должен следовать во время разговора.",
-    "Chat history" : "История чата",
     "The history of chat messages before the current message, starting with a message by the user" : "История сообщений в чате до текущего сообщения, начиная с сообщения пользователя",
     "Response message" : "Ответное сообщение",
     "The generated response as part of the conversation" : "Сгенерированный ответ в ходе беседы",
+    "Chat with tools" : "Чат с инструментами",
+    "Chat with the language model with tool calling support." : "Чат с языковой моделью с поддержкой вызова инструментов.",
+    "Tool message" : "Сообщение инструмента",
+    "The result of tool calls in the last interaction" : "Результат вызова инструментов в последнем взаимодействии",
+    "Available tools" : "Доступные инструменты",
+    "The available tools in JSON format" : "Доступные инструменты в формате JSON",
     "The response from the chat model" : "Ответ от чат-модели",
+    "Tool calls" : "Вызовы инструментов",
+    "Tools call instructions from the model in JSON format" : "Инструкции по вызову инструментов от модели в формате JSON",
     "Formalize text" : "Формализовать текст",
     "Takes a text and makes it sound more formal" : "Берется текст и делает его звучание более формальным",
     "Write a text that you want the assistant to formalize" : "Напишите текст, который вы хотите, чтобы ассистент оформил официально",
@@ -344,7 +427,12 @@ OC.L10N.register(
     "Original text" : "Оригинальный текст",
     "The original text to generate a headline for" : "Исходный текст для создания заголовка для",
     "The generated headline" : "Сгенерированный заголовок",
+    "Proofread" : "Проверка правописания",
+    "Proofreads a text and lists corrections" : "Проверяет текст и показывает исправления",
     "Text" : "Текст",
+    "The text to proofread" : "Текст для проверки",
+    "Corrections" : "Исправления",
+    "The corrections that should be made in your text" : "Исправления, которые следует внести в ваш текст",
     "Reformulate text" : "Переформулировать текст",
     "Takes a text and reformulates it" : "Берет текст и переформулирует его",
     "Write a text that you want the assistant to reformulate" : "Напишите текст, который вы хотите, чтобы ассистент переформулировал",
@@ -380,21 +468,13 @@ OC.L10N.register(
     "Generate headline" : "Сгенерировать заголовок",
     "Summarizes text by reducing its length without losing key information." : "Обобщает текст, сокращая его длину без потери ключевой информации.",
     "Extracts topics from a text and outputs them separated by commas." : "Извлекает темы из текста и выводит их через запятую.",
-    "Education Edition" : "Набор приложений для образовательных учреждений",
-    "File name is a reserved word" : "Имя файла является зарезервированным словом",
-    "File name contains at least one invalid character" : "Имя файла содержит по крайней мере один недопустимый символ",
-    "File name is too long" : "Имя файла слишком длинное.",
-    "Users" : "Пользователи",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s предоставил(а) вам доступ к «%2$s» и хочет добавить:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s предоставил(а) вам доступ к «%2$s» и хочет добавить",
-    "»%s« added a note to a file shared with you" : "%s добавил(а) примечание к файлу, к которому вам открыт доступ",
-    "Open »%s«" : "Открыть «%s»",
-    "%1$s shared »%2$s« with you" : "%1$s предоставил(а) вам доступ к «%2$s»",
-    "%1$s shared »%2$s« with you." : "%1$s предоставил(а) вам доступ к «%2$s».",
-    "Click the button below to open it." : "Нажмите расположенную ниже кнопку для перехода к полученному общему ресурсу.",
+    "Organisation" : "Организация",
     "File is currently busy, please try again later" : "Файл в данный момент используется, повторите попытку позже.",
     "Cannot download file" : "Не удалось скачать файл",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Убедитесь, что в корне каталога данных присутствует файл «.ocdata».",
-    "Path contains files shared with you" : "Путь содержит файлы, к которым вы предоставили общий доступ"
+    "Cannot write into \"apps\" directory." : "Не удалось выполнить запись в каталог «apps».",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Обычно это можно исправить, предоставлением веб-серверу права для записи в каталог приложений или отключением магазина приложений в файле конфигурации.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Параметр <code>mbstring.func_overload</code> установлен в <code>%s</code>, но ожидается значение <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Чтобы исправить эту проблему установите параметр <code>mbstring.func_overload</code> в значение <code>0</code> в php.ini.",
+    "Login is too long" : "Имя пользователя слишком длинное"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
